// problem: not expression is currently returning false on values other than true, false or null

@function truthyfalsey($bool: null) {
  @if not $bool {
    @return falsey;
  } @else {
    @return truthy;
  }
}

.test {
  debug: truthyfalsey(true); // expect truthy
  debug: truthyfalsey(false); // expect falsey
  debug: truthyfalsey(); // expect falsey (default arg is null)
  debug: truthyfalsey(5); // expect truthy
  debug: truthyfalsey(string); // expect truthy
  debug: truthyfalsey((alpha: 1, bravo: 2)); // expect truthy
  debug: truthyfalsey(this is a list); // expect truthy
  debug: truthyfalsey('true'); // expect truthy
}
