.strings {
  // Strings are tokenized as units, so their contents shouldn't affect anything
  // else.
  --text: "foo";
  --bang: "!";
  --semicolon: ";";
  --square: "][";
  --curly: "}{";
  --parens: ")(";
}
