@mixin transition( $prefix_properties, $transitions... ) {

    @if not str-index( inspect( $transitions ), ',') {
        $transitions: ( $transitions );
    }

    @each $prefix in -webkit-, -moz-, -ms-, -o-, '' {

        $prefixed: '';

        @each $transition in $transitions {

            @if $prefix_properties and '' != $prefix {
                $prefixed: #{$prefix}$transition,$transition;
            } @else {
                $prefixed: $transition;
            }


        }

        #{$prefix}transition: $prefixed;
    }
}

.my-element {
    @include transition( true, transform 0.25s linear );
}
