foo {
  // c-1: change-color(red,$saturation:-1);
  c0: change-color(red,$saturation:0);
  c1: change-color(red,$saturation:1);
  c2: change-color(red,$saturation:2);
  c3: change-color(red,$saturation:3);
  c4: change-color(red,$saturation:4);
  c5: change-color(red,$saturation:5);
  c6: change-color(red,$saturation:6);
  c7: change-color(red,$saturation:7);
  c8: change-color(red,$saturation:8);
  c9: change-color(red,$saturation:9);
  c10: change-color(red,$saturation:10);
  c11: change-color(red,$saturation:11);
  c12: change-color(red,$saturation:12);
  c13: change-color(red,$saturation:13);
  c14: change-color(red,$saturation:14);
  c15: change-color(red,$saturation:15);
  c16: change-color(red,$saturation:16);
  c17: change-color(red,$saturation:17);
  c18: change-color(red,$saturation:18);
  c19: change-color(red,$saturation:19);
  c20: change-color(red,$saturation:20);
  c21: change-color(red,$saturation:21);
  c22: change-color(red,$saturation:22);
  c23: change-color(red,$saturation:23);
  c24: change-color(red,$saturation:24);
  c25: change-color(red,$saturation:25);
  c26: change-color(red,$saturation:26);
  c27: change-color(red,$saturation:27);
  c28: change-color(red,$saturation:28);
  c29: change-color(red,$saturation:29);
  c30: change-color(red,$saturation:30);
  c31: change-color(red,$saturation:31);
  c32: change-color(red,$saturation:32);
  c33: change-color(red,$saturation:33);
  c34: change-color(red,$saturation:34);
  c35: change-color(red,$saturation:35);
  c36: change-color(red,$saturation:36);
  c37: change-color(red,$saturation:37);
  c38: change-color(red,$saturation:38);
  c39: change-color(red,$saturation:39);
  c40: change-color(red,$saturation:40);
  c41: change-color(red,$saturation:41);
  c42: change-color(red,$saturation:42);
  c43: change-color(red,$saturation:43);
  c44: change-color(red,$saturation:44);
  c45: change-color(red,$saturation:45);
  c46: change-color(red,$saturation:46);
  c47: change-color(red,$saturation:47);
  c48: change-color(red,$saturation:48);
  c49: change-color(red,$saturation:49);
  c50: change-color(red,$saturation:50);
  c51: change-color(red,$saturation:51);
  c52: change-color(red,$saturation:52);
  c53: change-color(red,$saturation:53);
  c54: change-color(red,$saturation:54);
  c55: change-color(red,$saturation:55);
  c56: change-color(red,$saturation:56);
  c57: change-color(red,$saturation:57);
  c58: change-color(red,$saturation:58);
  c59: change-color(red,$saturation:59);
  c60: change-color(red,$saturation:60);
  c61: change-color(red,$saturation:61);
  c62: change-color(red,$saturation:62);
  c63: change-color(red,$saturation:63);
  c64: change-color(red,$saturation:64);
  c65: change-color(red,$saturation:65);
  c66: change-color(red,$saturation:66);
  c67: change-color(red,$saturation:67);
  c68: change-color(red,$saturation:68);
  c69: change-color(red,$saturation:69);
  c70: change-color(red,$saturation:70);
  c71: change-color(red,$saturation:71);
  c72: change-color(red,$saturation:72);
  c73: change-color(red,$saturation:73);
  c74: change-color(red,$saturation:74);
  c75: change-color(red,$saturation:75);
  c76: change-color(red,$saturation:76);
  c77: change-color(red,$saturation:77);
  c78: change-color(red,$saturation:78);
  c79: change-color(red,$saturation:79);
  c80: change-color(red,$saturation:80);
  c81: change-color(red,$saturation:81);
  c82: change-color(red,$saturation:82);
  c83: change-color(red,$saturation:83);
  c84: change-color(red,$saturation:84);
  c85: change-color(red,$saturation:85);
  c86: change-color(red,$saturation:86);
  c87: change-color(red,$saturation:87);
  c88: change-color(red,$saturation:88);
  c89: change-color(red,$saturation:89);
  c90: change-color(red,$saturation:90);
  c91: change-color(red,$saturation:91);
  c92: change-color(red,$saturation:92);
  c93: change-color(red,$saturation:93);
  c94: change-color(red,$saturation:94);
  c95: change-color(red,$saturation:95);
  c96: change-color(red,$saturation:96);
  c97: change-color(red,$saturation:97);
  c98: change-color(red,$saturation:98);
  c99: change-color(red,$saturation:99);
  c100: change-color(red,$saturation:100);
  // c101: change-color(red,$saturation:101);
}
