$map: (
  foo: bar,
  baz: monkey,
);

.css {
  @each $key, $value in $map {
    #{$key}: $value;
  }
}

$list: one two, three four five, six seven;

.list {
  @each $foo, $bar, $baz in $list {
    #{$foo}: $bar $baz;
  }
}
