div {
  :-moz-any(ol p.blah, ul, menu, dir) :-moz-any(ol span + h1, ul, menu, dir) ul {
    list-style-type: square;
  }
  :-moz-any(ol span + h1, ul, menu, dir) ul {
    list-style-type: square;
  }
  :foo(p div) {
    hi: hi;
  }
  :foo(ol) {
    hi: hi;
  }
}
