.sprites-nav, .mw_nav_button[data-ur-state="disabled"] { color: red; }

.sprites-nav_up, .mw_nav_button[data-ur-state="enabled"] { color: green; }

.mw_nav_button { float: right; width: 30px; height: 30px; margin: 10px 10px 10px 0; overflow: hidden; }
