$x: 3px;
/* comment 1 */
@if/* pre 1 */$x == 3px/* post 1 */{
    /* if 1 */
}
/* comment 2 */
@elseif/* pre 2 */$x == 2px/* post 2 */{
    /* else if 2 */
}
/* comment 3 */
@else/* middle 3 */if/* pre 3  */$x == 3px/* post 3 */{
    /* else if 3 */
}
/* comment 4 */
@else/* post 4 */{
    /* else 4 */
}
/* comment 5 */