foo {
  @at-root {
    %placeholder {
      color: red;
    }
  }

  baz {
    @at-root {
      %other-placeholder {
        color: blue;
      }
    }
  }
}

bar {
  @extend %placeholder;
}

baz {
  @extend %other-placeholder;
}
