@media only screen {
  .foo {
    content: bar;

    @media (min-width: 1337px) {
      content: baz;
    }

    content: foo;
  }
}

$foo: "(min-width: 0) and (max-width: 599px),  (min-width: 600px) and (max-width: 899px)";
@media #{$foo} {
  $bar: "(min-width: 0) and (max-width: 599px)";
  @media #{$bar} {
    .foo {
      content: bar;
    }
  }
}
