foo {
  test-1: true;
  test-2: true;
  test-3: true;
  test-4: true;
  test-5: true;
  test-6: true;
  test-7: true;
  test-8: true;
  test-9: true;
  test-10: true;
  test-11: true;
  test-12: true;
  test-13: false;
  test-14: false;
  test-15: false;
  test-16: false;
  test-17: false;
  test-18: false;
  test-19: false;
  test-20: false;
  test-21: true;
  test-22: true;
  test-23: true;
  test-24: true;
  test-25: false;
  test-26: false;
  test-27: false;
  test-28: false;
  test-29: false;
  test-30: false;
  test-31: false;
  test-32: false;
  test-33: false;
  test-34: false;
  test-35: false;
  test-36: false;
  test-37: true;
  test-38: true;
  test-39: true;
  test-40: true;
  test-41: false;
  test-42: false;
  test-43: false;
  test-44: false;
  test-45: false;
  test-46: false;
  test-47: false;
  test-48: false;
  test-49: true;
  test-50: true;
  test-51: true;
  test-52: true;
  test-53: false;
  test-54: false;
  test-55: false;
  test-56: false;
  test-57: true;
  test-58: true;
  test-59: true;
  test-60: true; }
