
@mixin flex($grow: 1, $shrink: null, $basis: null) {
  -webkit-box-flex: $grow;
  -webkit-flex: $grow $shrink $basis;
  -moz-box-flex: $grow;
  -moz-flex: $grow $shrink $basis;
  -ms-flex: $grow $shrink $basis;
  flex: $grow $shrink $basis;
}

[flex] {
  @include flex;
}
