foo bar baz{bam:true}baz foo bar{bam:true}foo+bar baz{bam:true}baz foo+bar{bam:true}foo>bar baz{bam:true}baz foo>bar{bam:true}foo ~ bar baz{bam:true}baz foo ~ bar{bam:true}foo /deep/ bar baz{bam:true}baz foo /deep/ bar{bam:true}
