.result{length:4;content:.foo .bar a .bar,.baz .where .qux.waldo .final;index:1;length:1;content:.foo;index:2;length:1;content:.bar a;index:3;length:2;content:.bar,.baz;index:4;length:1;content:.where .qux.waldo .final}
