$path: "images";
$file: "kittens.jpg";
$image: "";
$other: file_join("images", "kittens.jpg");

@if $image != none {
	$image: url(file_join($path, $file));
}
body {
	background: $image;
	color: $other;
}
