foo {
  -quotes: 'this-string' == 'this-string';
  -quotes: this-string == 'this-string';
  -quotes: 'this-string' == "this-string";
  -quotes: 'this-string' == '"this-string"';
  -quotes: '"this-string"' == "'this-string'";
  foo: this-string;
  foo: 'this-string';
  foo: "this-string";
  foo: '"this-string"';
  foo: "'this-string'";
}
