a {
  hey: ho;
  hugabug: third second;
  hugabug: kwd-y kwd-x;
  goo: boo hoo;
  no: parameters here;
  /* end of hux */
  flugablug: pug flug glug;
  flugablug: pug mug glug; }
  a div, a span {
    some: nested stuff; }
    a div foo, a div bar, a span foo, a span bar {
      more: stuff so forth;
      blah: blah; }

div {
  blah: blah from a variable blah; }
