@mixin simple-media-query($max-width, $min-width) {
      @media only screen and (max-width: $max-width) and (min-width: $min-width) {
        @content;
      }
}

@mixin test($value) {
    border-color: $value;
}

body 
{
    @include test("#ccc");
    @include simple-media-query(900px, 400px) {
        border-color: black;
    }
}