div span,div p,div span{color:red}div a.foo.bar.foo{color:green}div:nth(-3){color:blue}@-webkit-keyframes{from{left:0px;10%{whatever:hoo}}to{left:200px}}@whatever{div{blah:blah}div stuff{blah:bloh}}a,b{color:red}a c,a d,b c,b d{height:10px}a c e,a c f,a d e,a d f,b c e,b c f,b d e,b d f{width:12px}
