// test for libsass 694:
// parser should be smarter about handling quoted quotes

$str: '{' + '"foo": "bar"' + '}';
$str2: '"hello world"';
$str3: "hello world";
.interpolation-test {
  test: "#{$str}";
  test: "#{$str2}";
  test: "#{$str3}";
}
