@charset "UTF-8";
/*
Theme Name: Moovweb Time
*/
* {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box; }

/*! normalize.css v2.1.2 | MIT License | git.io/normalize */
/* ==========================================================================
   HTML5 display definitions
   ========================================================================== */
/**
 * Correct `block` display not defined in IE 8/9.
 */
article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
nav,
section,
summary {
  display: block; }

/**
 * Correct `inline-block` display not defined in IE 8/9.
 */
audio,
canvas,
video {
  display: inline-block; }

/**
 * Prevent modern browsers from displaying `audio` without controls.
 * Remove excess height in iOS 5 devices.
 */
audio:not([controls]) {
  display: none;
  height: 0; }

/**
 * Address styling not present in IE 8/9.
 */
[hidden] {
  display: none; }

/* ==========================================================================
   Base
   ========================================================================== */
/**
 * 1. Set default font family to sans-serif.
 * 2. Prevent iOS text size adjust after orientation change, without disabling
 *    user zoom.
 */
html {
  font-family: sans-serif;
  /* 1 */
  -ms-text-size-adjust: 100%;
  /* 2 */
  -webkit-text-size-adjust: 100%;
  /* 2 */ }

/**
 * Remove default margin.
 */
body {
  margin: 0; }

/* ==========================================================================
   Links
   ========================================================================== */
/**
 * Address `outline` inconsistency between Chrome and other browsers.
 */
a:focus {
  outline: thin dotted; }

/**
 * Improve readability when focused and also mouse hovered in all browsers.
 */
a:active,
a:hover {
  outline: 0; }

/* ==========================================================================
   Typography
   ========================================================================== */
/**
 * Address variable `h1` font-size and margin within `section` and `article`
 * contexts in Firefox 4+, Safari 5, and Chrome.
 */
h1 {
  font-size: 2em;
  margin: 0.67em 0; }

/**
 * Address styling not present in IE 8/9, Safari 5, and Chrome.
 */
abbr[title] {
  border-bottom: 1px dotted; }

/**
 * Address style set to `bolder` in Firefox 4+, Safari 5, and Chrome.
 */
b,
strong {
  font-weight: bold; }

/**
 * Address styling not present in Safari 5 and Chrome.
 */
dfn {
  font-style: italic; }

/**
 * Address differences between Firefox and other browsers.
 */
hr {
  -moz-box-sizing: content-box;
  box-sizing: content-box;
  height: 0; }

/**
 * Address styling not present in IE 8/9.
 */
mark {
  background: #ff0;
  color: #000; }

/**
 * Correct font family set oddly in Safari 5 and Chrome.
 */
code,
kbd,
pre,
samp {
  font-family: monospace, serif;
  font-size: 1em; }

/**
 * Improve readability of pre-formatted text in all browsers.
 */
pre {
  white-space: pre-wrap; }

/**
 * Set consistent quote types.
 */
q {
  quotes: "\201C" "\201D" "\2018" "\2019"; }

/**
 * Address inconsistent and variable font size in all browsers.
 */
small {
  font-size: 80%; }

/**
 * Prevent `sub` and `sup` affecting `line-height` in all browsers.
 */
sub,
sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sup {
  top: -0.5em; }

sub {
  bottom: -0.25em; }

/* ==========================================================================
   Embedded content
   ========================================================================== */
/**
 * Remove border when inside `a` element in IE 8/9.
 */
img {
  border: 0; }

/**
 * Correct overflow displayed oddly in IE 9.
 */
svg:not(:root) {
  overflow: hidden; }

/* ==========================================================================
   Figures
   ========================================================================== */
/**
 * Address margin not present in IE 8/9 and Safari 5.
 */
figure {
  margin: 0; }

/* ==========================================================================
   Forms
   ========================================================================== */
/**
 * Define consistent border, margin, and padding.
 */
fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em; }

/**
 * 1. Correct `color` not being inherited in IE 8/9.
 * 2. Remove padding so people aren't caught out if they zero out fieldsets.
 */
legend {
  border: 0;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * 1. Correct font family not being inherited in all browsers.
 * 2. Correct font size not being inherited in all browsers.
 * 3. Address margins set differently in Firefox 4+, Safari 5, and Chrome.
 */
button,
input,
select,
textarea {
  font-family: inherit;
  /* 1 */
  font-size: 100%;
  /* 2 */
  margin: 0;
  /* 3 */ }

/**
 * Address Firefox 4+ setting `line-height` on `input` using `!important` in
 * the UA stylesheet.
 */
button,
input {
  line-height: normal; }

/**
 * Address inconsistent `text-transform` inheritance for `button` and `select`.
 * All other form control elements do not inherit `text-transform` values.
 * Correct `button` style inheritance in Chrome, Safari 5+, and IE 8+.
 * Correct `select` style inheritance in Firefox 4+ and Opera.
 */
button,
select {
  text-transform: none; }

/**
 * 1. Avoid the WebKit bug in Android 4.0.* where (2) destroys native `audio`
 *    and `video` controls.
 * 2. Correct inability to style clickable `input` types in iOS.
 * 3. Improve usability and consistency of cursor style between image-type
 *    `input` and others.
 */
button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  -webkit-appearance: button;
  /* 2 */
  cursor: pointer;
  /* 3 */ }

/**
 * Re-set default cursor for disabled elements.
 */
button[disabled],
html input[disabled] {
  cursor: default; }

/**
 * 1. Address box sizing set to `content-box` in IE 8/9.
 * 2. Remove excess padding in IE 8/9.
 */
input[type="checkbox"],
input[type="radio"] {
  box-sizing: border-box;
  /* 1 */
  padding: 0;
  /* 2 */ }

/**
 * 1. Address `appearance` set to `searchfield` in Safari 5 and Chrome.
 * 2. Address `box-sizing` set to `border-box` in Safari 5 and Chrome
 *    (include `-moz` to future-proof).
 */
input[type="search"] {
  -webkit-appearance: textfield;
  /* 1 */
  -moz-box-sizing: content-box;
  -webkit-box-sizing: content-box;
  /* 2 */
  box-sizing: content-box; }

/**
 * Remove inner padding and search cancel button in Safari 5 and Chrome
 * on OS X.
 */
input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none; }

/**
 * Remove inner padding and border in Firefox 4+.
 */
button::-moz-focus-inner,
input::-moz-focus-inner {
  border: 0;
  padding: 0; }

/**
 * 1. Remove default vertical scrollbar in IE 8/9.
 * 2. Improve readability and alignment in all browsers.
 */
textarea {
  overflow: auto;
  /* 1 */
  vertical-align: top;
  /* 2 */ }

/* ==========================================================================
   Tables
   ========================================================================== */
/**
 * Remove most spacing between table cells.
 */
table {
  border-collapse: collapse;
  border-spacing: 0; }

@font-face {
  font-family: 'icomoon';
  src: url("styles/icons/fonts/icomoon.eot"); }
@font-face {
  font-family: 'icomoon';
  src: url(data:application/x-font-ttf;charset=utf-8;base64, ) format("truetype"), url(data:application/font-woff;charset=utf-8;base64, ) format("woff");
  font-weight: normal;
  font-style: normal; }
/* Use the following CSS code if you want to use data attributes for inserting your icons */
[data-icon]:before {
  font-family: 'icomoon';
  content: attr(data-icon);
  speak: none;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased; }

/* Use the following CSS code if you want to have a class per icon */
/*
Instead of a list of all class selectors,
you can use the generic selector below, but it's slower:
[class*="icon-"] {
*/
.icon-googeplus:before, .icon-moovweblogo:before, .main-header-logo:before, .blog-logo:before, .icon-wifi:before, .icon-twitter:before, .icon-speechbubble:before, .icon-speech:before, .icon-rocket:before, .icon-linkedin:before, .icon-lightning:before, .icon-facebook:before, .icon-clipboard:before, .icon-round-wifi:before, .category-icon-news:before, .icon-round-twitter:before, .icon-round-speechbubble:before, .category-icon-oped:before, .icon-round-speech:before, .icon-round-rocket:before, .category-icon-launch:before, .icon-round-linkedin:before, .icon-round-lightning:before, .icon-round-facebook:before, .icon-round-clipboard:before, .icon-round-googleplus:before {
  font-family: 'icomoon';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased; }

.icon-moovweblogo:before, .main-header-logo:before, .blog-logo:before {
  content: "\e000"; }

.icon-round-googleplus:before {
  content: "\e001"; }

.icon-googeplus:before {
  content: "\e002"; }

.icon-wifi:before {
  content: "\e003"; }

.icon-twitter:before {
  content: "\e004"; }

.icon-speechbubble:before {
  content: "\e005"; }

.icon-speech:before {
  content: "\e006"; }

.icon-rocket:before {
  content: "\e007"; }

.icon-linkedin:before {
  content: "\e008"; }

.icon-lightning:before {
  content: "\e009"; }

.icon-facebook:before {
  content: "\e00a"; }

.icon-clipboard:before {
  content: "\e00b"; }

.icon-round-wifi:before, .category-icon-news:before {
  content: "\e00c"; }

.icon-round-twitter:before {
  content: "\e00d"; }

.icon-round-speechbubble:before, .category-icon-oped:before {
  content: "\e00e"; }

.icon-round-speech:before {
  content: "\e00f"; }

.icon-round-rocket:before, .category-icon-launch:before {
  content: "\e010"; }

.icon-round-linkedin:before {
  content: "\e011"; }

.icon-round-lightning:before {
  content: "\e012"; }

.icon-round-facebook:before {
  content: "\e013"; }

.icon-round-clipboard:before {
  content: "\e014"; }

.visuallyhidden {
  border: 0;
  clip: rect(0 0 0 0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px; }

.visuallyhidden.focusable:active,
.visuallyhidden.focusable:focus {
  clip: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  position: static;
  width: auto; }

.clearfix:before, .clearfix:after {
  content: " ";
  display: table; }
.clearfix:after {
  clear: both; }

.invisible {
  visibility: hidden; }

.hide-text {
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden; }

.round-button, .blog-share, .round-button-green, .home-banner-link-circle, .form-submit-button, .feature2-item:nth-of-type(2n) .feature2-item-link, .comment-form #submit, .panel-item:nth-of-type(2n) .panel-link {
  display: inline-block;
  padding: 10px 25px;
  background: #00ac4d;
  text-align: center;
  text-decoration: none;
  color: white;
  line-height: 20px;
  border-radius: 20px;
  margin: 6px 0 10px;
  text-transform: uppercase;
  font-size: 13px;
  letter-spacing: .18em;
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
  .round-button:visited, .blog-share:visited, .round-button:link, .blog-share:link, .round-button-green:visited, .home-banner-link-circle:visited, .form-submit-button:visited, .feature2-item:nth-of-type(2n) .feature2-item-link:visited, .comment-form #submit:visited, .panel-item:nth-of-type(2n) .panel-link:visited, .round-button-green:link, .home-banner-link-circle:link, .form-submit-button:link, .feature2-item:nth-of-type(2n) .feature2-item-link:link, .comment-form #submit:link, .panel-item:nth-of-type(2n) .panel-link:link {
    background: #00ac4d;
    text-decoration: none;
    color: white; }
  .round-button:hover, .blog-share:hover, .round-button-green:hover, .home-banner-link-circle:hover, .form-submit-button:hover, .feature2-item:nth-of-type(2n) .feature2-item-link:hover, .comment-form #submit:hover, .panel-item:nth-of-type(2n) .panel-link:hover {
    background: #00c658; }

.round-button-cyan, .feature2-item:nth-of-type(4n) .feature2-item-link, .feature2-item-link, .panel-item:nth-of-type(4n) .panel-link, .panel-link {
  display: inline-block;
  padding: 10px 25px;
  background: #00b4ea;
  text-align: center;
  text-decoration: none;
  color: white;
  line-height: 20px;
  border-radius: 20px;
  margin: 6px 0 10px;
  text-transform: uppercase;
  font-size: 13px;
  letter-spacing: .18em;
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
  .round-button-cyan:visited, .feature2-item:nth-of-type(4n) .feature2-item-link:visited, .feature2-item-link:visited, .panel-item:nth-of-type(4n) .panel-link:visited, .panel-link:visited, .round-button-cyan:link, .feature2-item:nth-of-type(4n) .feature2-item-link:link, .feature2-item-link:link, .panel-item:nth-of-type(4n) .panel-link:link, .panel-link:link {
    background: #00b4ea;
    text-decoration: none;
    color: white; }
  .round-button-cyan:hover, .feature2-item:nth-of-type(4n) .feature2-item-link:hover, .feature2-item-link:hover, .panel-item:nth-of-type(4n) .panel-link:hover, .panel-link:hover {
    background: #04c5ff; }

.round-button-blue, .feature2-item:nth-of-type(3n) .feature2-item-link, .panel-item:nth-of-type(3n) .panel-link {
  display: inline-block;
  padding: 10px 25px;
  background: #037bac;
  text-align: center;
  text-decoration: none;
  color: white;
  line-height: 20px;
  border-radius: 20px;
  margin: 6px 0 10px;
  text-transform: uppercase;
  font-size: 13px;
  letter-spacing: .18em;
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
  .round-button-blue:visited, .feature2-item:nth-of-type(3n) .feature2-item-link:visited, .panel-item:nth-of-type(3n) .panel-link:visited, .round-button-blue:link, .feature2-item:nth-of-type(3n) .feature2-item-link:link, .panel-item:nth-of-type(3n) .panel-link:link {
    background: #037bac;
    text-decoration: none;
    color: white; }
  .round-button-blue:hover, .feature2-item:nth-of-type(3n) .feature2-item-link:hover, .panel-item:nth-of-type(3n) .panel-link:hover {
    background: #038dc5; }

.dark-links a, .blog-control a, .blog-title a, .blog-part-category a, .blog-category a, .dark-links a:link, .blog-control a:link, .blog-title a:link, .blog-part-category a:link, .blog-category a:link, .dark-links a:visited, .blog-control a:visited, .blog-title a:visited, .blog-part-category a:visited, .blog-category a:visited {
  color: #4c4c4c; }
.dark-links a:hover, .blog-control a:hover, .blog-title a:hover, .blog-part-category a:hover, .blog-category a:hover, .dark-links a:active, .blog-control a:active, .blog-title a:active, .blog-part-category a:active, .blog-category a:active {
  color: #7f7f7f; }

.m-gray-links a, .blog-subtitle a, .m-gray-links a:link, .blog-subtitle a:link, .m-gray-links a:visited, .blog-subtitle a:visited {
  color: #747474; }
.m-gray-links a:hover, .blog-subtitle a:hover, .m-gray-links a:active, .blog-subtitle a:active {
  color: #a7a7a7; }

.green {
  color: #00ac4d; }

.blue {
  color: #0097d5; }

.cyan {
  color: #00b4ea; }

.greenlink, .event-upcoming-link {
  color: #00ac4d;
  -webkit-transition: all 300 ease;
  -moz-transition: all 300 ease;
  transition: all 300 ease; }
  .greenlink:link, .event-upcoming-link:link, .greenlink:visited, .event-upcoming-link:visited {
    color: #00ac4d; }
  .greenlink:hover, .event-upcoming-link:hover, .greenlink:active, .event-upcoming-link:active {
    color: #00df64; }

.circle-link {
  color: #00ac4d;
  text-transform: uppercase;
  letter-spacing: 0.1em;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  transition: all 0.2s ease; }
  .circle-link:link, .circle-link:visited {
    color: #00ac4d; }
  .circle-link:hover {
    color: #00df64; }
  .circle-link:after {
    content: '\2022';
    font-size: 50px;
    position: relative;
    top: 9px;
    left: 1px; }

* {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box; }

body, html {
  height: 100%; }

.main-heading {
  position: absolute;
  top: -100%; }

.master-wrapper {
  min-height: 100%;
  margin-bottom: -245px; }
  .master-wrapper:after {
    content: " ";
    display: block;
    height: 245px; }

body {
  font-family: 'Lato', sans-serif;
  font-weight: 300;
  font-size: 16px;
  line-height: 20px;
  color: #4c4c4c;
  letter-spacing: 0.05em;
  background: white; }

p {
  line-height: 20px;
  margin: 0 0 15px;
  font-size: 14px;
  line-height: 20px;
  letter-spacing: .02em; }
  @media screen and (min-width: 960px) {
    p {
      font-size: 16px;
      line-height: 25px;
      margin: 0 0 20px; } }

a, a:link, a:visited {
  color: #037bac;
  text-decoration: none;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  transition: all 0.2s ease; }

a:hover, a:active {
  color: #049fde; }
  a:hover .circle-link, a:active .circle-link {
    background: #049fde; }

hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
  margin: 1em 0;
  padding: 0; }

audio,
canvas,
img,
video {
  vertical-align: middle; }

fieldset {
  border: 0;
  margin: 0;
  padding: 0; }

textarea {
  resize: vertical; }

h1, .h1 {
  margin: 0 0 10px;
  font-size: 35px;
  line-height: 40px;
  font-weight: 700;
  letter-spacing: 0.02em; }
  @media screen and (min-width: 960px) {
    h1, .h1 {
      font-size: 36px;
      margin: 0 0 15px; } }

h2, .h2 {
  margin: 0 0 10px;
  font-size: 30px;
  line-height: 35px;
  font-weight: 700;
  letter-spacing: 0.02em; }
  @media screen and (min-width: 960px) {
    h2, .h2 {
      font-size: 32px; } }

h3, .h3 {
  margin: 0 0 10px;
  line-height: 30px;
  font-size: 20px; }
  @media screen and (min-width: 960px) {
    h3, .h3 {
      font-size: 22px; } }

h4, .h4 {
  margin: 0 0 10px;
  line-height: 25px;
  font-size: 15px; }
  @media screen and (min-width: 960px) {
    h4, .h4 {
      font-size: 18px; } }

h5, .h5 {
  margin: 0 0 10px;
  line-height: 20px;
  font-size: 13px; }
  @media screen and (min-width: 960px) {
    h5, .h5 {
      font-size: 15px;
      margin: 0 0 15px; } }

h6, .h6 {
  margin: 0 0 10px;
  line-height: 20px;
  font-size: 12px; }
  @media screen and (min-width: 960px) {
    h6, .h6 {
      font-size: 13px;
      margin: 0 0 15px; } }

blockquote, blockquote p {
  color: #747474;
  padding: 0;
  margin: 0 0 10px;
  font-size: 20px;
  line-height: 25px;
  font-weight: 700;
  letter-spacing: 0.05em;
  position: relative; }
  blockquote > p, blockquote p > p {
    text-indent: -.5em; }
    blockquote > p:before, blockquote p > p:before {
      content: "\201C";
      position: relative; }
    blockquote > p:after, blockquote p > p:after {
      content: "\201D";
      position: relative;
      left: 2px; }

.blog-content img {
  display: block;
  margin: 20px auto;
  max-width: 100%;
  height: auto; }
.blog-content audio, .blog-content video {
  max-width: 100%; }

.alignright {
  float: right;
  display: inline;
  margin: 0 0 10px 15px; }

.alignleft {
  float: left;
  display: inline;
  margin: 0 15px 10px 0; }

ul, ol {
  margin: 0 0 15px;
  padding: 0 18px; }

li {
  margin: 0 0 5px;
  font-size: 14px; }
  @media screen and (min-width: 960px) {
    li {
      font-size: 16px; } }

b, strong {
  font-weight: 400; }

.main-error {
  margin-top: 20px;
  font-size: 60px;
  line-height: 60px; }

.map {
  position: relative;
  padding-bottom: 350px;
  /* 16:9 */
  height: 0; }
  .map iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%; }

.content-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 10px; }
  .content-wrapper:before, .content-wrapper:after {
    content: " ";
    display: table; }
  .content-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .content-wrapper {
      max-width: 60em; } }

.content-item-description {
  font-size: 14px;
  line-height: 20px;
  font-weight: 300;
  letter-spacing: .06em; }
  @media screen and (min-width: 960px) {
    .content-item-description {
      font-size: 16px;
      line-height: 25px; } }

.content-title {
  color: #037bac;
  font-weight: 400;
  text-transform: uppercase; }
  @media screen and (min-width: 960px) {
    .content-title {
      margin: 0 0 15px;
      line-height: 35px;
      font-size: 30px; } }

.content-item-title {
  color: #037bac;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  @media screen and (min-width: 960px) {
    .content-item-title {
      font-size: 20px; } }

.content-item-subtitle {
  color: #037bac;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 15px;
  line-height: 20px;
  font-weight: 300; }
  @media screen and (min-width: 960px) {
    .content-item-subtitle {
      font-size: 16px; } }

.content-center-wrapper {
  padding: 20px 10px;
  font-size: 16px; }
  .content-center-wrapper p {
    font-size: 16px; }
  @media screen and (min-width: 960px) {
    .content-center-wrapper {
      font-size: 18px;
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 65.5914%;
      margin-left: 17.2043%; }
      .content-center-wrapper p {
        font-size: 18px; }
      .content-center-wrapper:last-child {
        margin-right: 0; } }

.lt-ie9 .footer-gartner {
  display: none !important; }
.lt-ie9 .blog-sidebar,
.lt-ie9 .blog-meta,
.lt-ie9 .blog-content-wrapper,
.lt-ie9 .panel-item,
.lt-ie9 .large-panel-item,
.lt-ie9 .content1-item-imagewrapper,
.lt-ie9 .customer-list-item,
.lt-ie9 .content3-item-wrapper,
.lt-ie9 .flexcontent3-item-wrapper,
.lt-ie9 .date-item,
.lt-ie9 .menu-header-menu-container,
.lt-ie9 .content6-item-subwrapper,
.lt-ie9 .content4-sideimagewrapper,
.lt-ie9 .pressroom-column,
.lt-ie9 .form2-content {
  margin-right: 0 !important; }
.lt-ie9 .pricing-table {
  display: none !important; }
.lt-ie9 .pricing-table-mobile {
  display: table !important; }
.lt-ie9 .pricing-wrapper {
  padding-right: 60px;
  padding-left: 60px; }
.lt-ie9 .content5-item {
  display: inline-block;
  margin-right: 0 !important; }

.page-header {
  background: #f5f6f6; }

.page-header-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 30px 10px; }
  .page-header-wrapper:before, .page-header-wrapper:after {
    content: " ";
    display: table; }
  .page-header-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .page-header-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .page-header-wrapper {
      padding: 80px 10px; } }

.page-heading {
  padding: 0 0 10px;
  text-align: center;
  border-bottom: 1px solid #4c4c4c;
  text-transform: uppercase;
  margin: 0 auto 15px; }
  @media screen and (min-width: 960px) {
    .page-heading {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 65.5914%;
      margin-left: 17.2043%; }
      .page-heading:last-child {
        margin-right: 0; } }

.page-description {
  text-align: center;
  font-size: 22px;
  line-height: 25px;
  font-weight: 300;
  margin: 0 auto; }
  @media screen and (min-width: 960px) {
    .page-description {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 65.5914%;
      margin-left: 17.2043%; }
      .page-description:last-child {
        margin-right: 0; } }

.page-content-wrapper {
  padding: 20px 0 0; }
  @media screen and (min-width: 960px) {
    .page-content-wrapper {
      padding: 30px 0 0; } }

.page-column {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .page-column:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .page-column {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .page-column:last-child {
        margin-right: 0; } }

.content-image-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px;
  text-align: center;
  margin-bottom: 10px; }
  .content-image-wrapper:before, .content-image-wrapper:after {
    content: " ";
    display: table; }
  .content-image-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .content-image-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .content-image-wrapper {
      padding: 0 10px; } }

.content-image {
  max-width: 100%;
  height: auto; }

.image-retina {
  max-width: 50%; }

.home-header {
  background: #f5f6f6;
  background-position: center bottom;
  background-repeat: no-repeat; }

.home-header-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 30px 10px; }
  .home-header-wrapper:before, .home-header-wrapper:after {
    content: " ";
    display: table; }
  .home-header-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .home-header-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .home-header-wrapper {
      padding: 100px 10px 80px; } }

.home-heading {
  padding: 0 0 5px;
  text-align: center;
  text-transform: uppercase;
  font-size: 26px;
  letter-spacing: 0.05em;
  font-weight: 400;
  line-height: 35px; }
  .home-heading:after {
    content: '';
    display: block;
    border-bottom: 1px solid #747474;
    max-width: 66%;
    margin: 0 auto;
    padding: 5px; }
  @media screen and (min-width: 960px) {
    .home-heading {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 82.7957%;
      margin-left: 8.60215%;
      max-width: none;
      line-height: 45px;
      font-size: 36px; }
      .home-heading:last-child {
        margin-right: 0; } }

.home-description {
  text-align: center;
  font-size: 16px;
  line-height: 25px;
  font-weight: 300;
  margin-bottom: 10px;
  letter-spacing: 0.05em;
  padding: 0 20px; }
  @media screen and (min-width: 960px) {
    .home-description {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 65.5914%;
      margin-left: 17.2043%;
      padding: 0;
      max-width: none;
      font-size: 22px;
      line-height: 25px;
      margin-bottom: 20px; }
      .home-description:last-child {
        margin-right: 0; } }

.home-link-wrapper {
  text-align: center; }
  @media screen and (min-width: 960px) {
    .home-link-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 82.7957%;
      margin-left: 8.60215%; }
      .home-link-wrapper:last-child {
        margin-right: 0; } }

.home-headerbreak {
  display: inline; }
  @media screen and (min-width: 960px) {
    .home-headerbreak {
      display: block; } }

.home-banner-link {
  font-size: 18px; }

.home-banner-link-circle {
  line-height: 35px;
  padding: 0 40px; }

.slider {
  *zoom: 1;
  display: block; }
  .slider:before, .slider:after {
    content: " ";
    display: table; }
  .slider:after {
    clear: both; }

.slider--gray {
  background: #f5f6f6; }

.slider--bordertop {
  border-top: 1px solid #dddddd; }

.slider--borderbottom {
  border-bottom: 1px solid #dddddd; }

.slider-heading {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 1px 10px;
  text-align: center;
  text-transform: uppercase;
  font-weight: 400;
  margin-bottom: 0;
  font-size: 25px; }
  .slider-heading:before, .slider-heading:after {
    content: " ";
    display: table; }
  .slider-heading:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .slider-heading {
      max-width: 60em; } }

.slider-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 10px 40px;
  position: relative; }
  .slider-wrapper:before, .slider-wrapper:after {
    content: " ";
    display: table; }
  .slider-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .slider-wrapper {
      max-width: 60em; } }

.slider-holder {
  overflow: hidden; }

.slider-list {
  *zoom: 1;
  display: block;
  padding: 0;
  margin-bottom: 0;
  -webkit-transition: margin 0.3s ease;
  -moz-transition: margin 0.3s ease;
  transition: margin 0.3s ease; }
  .slider-list:before, .slider-list:after {
    content: " ";
    display: table; }
  .slider-list:after {
    clear: both; }

.no-js .slider-item {
  display: block;
  float: left;
  margin-right: 14.28571%;
  width: 23.80952%;
  padding: 0;
  text-align: center;
  list-style: none;
  color: white;
  margin-bottom: 0; }
  .no-js .slider-item:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .no-js .slider-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 13.97849%;
      margin-bottom: 0; }
      .no-js .slider-item:last-child {
        margin-right: 0; }
      .no-js .slider-item:nth-child(6n) {
        margin-right: 0; }
      .no-js .slider-item:nth-child(6n+1) {
        clear: left; } }

.js .slider-item {
  margin-right: 0;
  float: left;
  list-style: none;
  text-align: center;
  margin-bottom: 0;
  padding: 5px; }
  @media screen and (min-width: 960px) {
    .js .slider-item {
      margin-right: 0;
      margin-bottom: 0; } }

@media screen and (max-width: 60em) {
  .slider-item:nth-child(3n) {
    margin-right: 0; } }

.slider-next {
  position: absolute;
  right: 0;
  top: 50%;
  margin-top: -10px;
  width: 20px;
  height: 20px;
  border-radius: 50%;
  background: #00ac4d;
  display: block;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden; }
  .slider-next:hover {
    background: #00df64; }
  .slider-next:before {
    content: '>';
    position: absolute;
    left: -15px;
    font-size: 18px;
    top: -1px;
    color: white; }

.slider-prev {
  position: absolute;
  left: 0;
  top: 50%;
  margin-top: -10px;
  width: 20px;
  height: 20px;
  border-radius: 50%;
  background: #00ac4d;
  display: block;
  text-indent: 100%;
  white-space: nowrap;
  overflow: hidden; }
  .slider-prev:hover {
    background: #00df64; }
  .slider-prev:before {
    content: '<';
    position: absolute;
    left: -15px;
    font-size: 18px;
    top: -1px;
    color: white; }

.slider-image {
  max-width: 100%;
  height: auto; }

.form-wrapper {
  position: relative;
  min-height: 320px; }

.form-items-wrapper {
  margin: 0 0 15px; }

.form-input {
  display: block;
  font-size: 16px;
  padding: 5px .5em;
  margin: 0;
  border: 1px solid #b0b0b0;
  width: 100%;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }

.form-label {
  display: block;
  width: 100%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
  line-height: 25px;
  text-transform: uppercase; }

.form-item {
  *zoom: 1;
  margin: 0 0 5px;
  padding: 0 5px; }
  .form-item:before, .form-item:after {
    content: " ";
    display: table; }
  .form-item:after {
    clear: both; }

.form-submit-wrapper {
  text-align: center; }

.form-submit-button {
  padding: 10 40px; }

.form--error {
  background: #FF9696;
  color: #522C31;
  border-color: #522C31; }

.form-item[name="FirstName"] {
  width: 50%;
  float: left; }

.form-item[name="LastName"] {
  width: 50%;
  float: left; }

.form-item[name="State"] {
  width: 33.333%;
  float: left; }

.form-item[name="Phone"] {
  width: 66.666%;
  float: left; }

.form-thankyou {
  position: absolute;
  display: none;
  margin: 10px 0 0 5px;
  width: 100%;
  text-align: center; }

.form-link-wrapper {
  text-align: center; }

.form-link {
  line-height: 35px;
  padding: 0 30px; }

.form-select {
  position: relative; }
  .form-select .form-input {
    background: transparent;
    border: 1px solid #b0b0b0;
    font-size: 16px;
    border-radius: 0;
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    text-indent: 0.01px;
    text-overflow: '';
    z-index: 99; }
  .form-select .form--error {
    background: #FF9696;
    color: #522C31;
    border-color: #522C31; }
  .form-select:after {
    content: '\25BC';
    position: absolute;
    right: 5px;
    top: 6px;
    color: #4c4c4c;
    pointer-events: none; }

.form-inline-select {
  position: relative;
  margin: 10px 0;
  display: block;
  text-align: center; }
  .form-inline-select select {
    min-width: 100%; }
  @media screen and (min-width: 960px) {
    .form-inline-select {
      display: inline-block;
      margin: 10px 5px; } }

.form2-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 10px 10px 20px; }
  .form2-wrapper:before, .form2-wrapper:after {
    content: " ";
    display: table; }
  .form2-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .form2-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .form2-wrapper {
      padding: 30px 10px; } }

.form2-content {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .form2-content:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .form2-content {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .form2-content:last-child {
        margin-right: 0; } }

.form2-formwrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .form2-formwrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .form2-formwrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .form2-formwrapper:last-child {
        margin-right: 0; } }

.form2-text {
  margin-bottom: 20px; }

.form2-title {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0 0 10px;
  font-size: 22px; }

.form2-imagewrapper {
  text-align: center;
  margin-bottom: 20px;
  padding: 10px 5px 0 0; }
  @media screen and (min-width: 960px) {
    .form2-imagewrapper {
      margin-bottom: 30px; } }

.form2-image {
  max-width: 100%;
  height: auto;
  box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.3); }

.form2-speakers {
  margin-bottom: 20px;
  padding: 10px 0 10px 0;
  *zoom: 1; }
  .form2-speakers:before, .form2-speakers:after {
    content: " ";
    display: table; }
  .form2-speakers:after {
    clear: both; }

.form2-speaker {
  float: left;
  width: 100%;
  border-bottom: 1px solid #dddddd;
  padding: 0 0 10px 0;
  *zoom: 1; }
  .form2-speaker:before, .form2-speaker:after {
    content: " ";
    display: table; }
  .form2-speaker:after {
    clear: both; }

.form2-speaker-image-wrapper {
  width: 25%;
  padding-right: 20px;
  float: left; }

.form2-speaker-image {
  max-width: 100%;
  border: 3px solid #dddddd; }

.form2-speaker-name {
  font-weight: 400;
  padding: 20px 20px 0 20px; }

.form2-speaker-title {
  font-weight: 300;
  display: block;
  font-style: italic; }

.form-quote-wrapper {
  border: 1px solid rgba(3, 123, 172, 0.3);
  font-size: 18px;
  margin: 0 0 30px;
  font-style: italic; }
  .form-quote-wrapper p {
    padding: 20px 40px;
    font-size: 16px;
    margin-bottom: 0; }
  @media screen and (min-width: 960px) {
    .form-quote-wrapper p {
      font-size: 18px;
      padding: 30px 40px; } }

.form-attritubtion {
  border-top: 1px solid rgba(3, 123, 172, 0.3); }
  .form-attritubtion p {
    font-weight: 400;
    color: #037bac;
    margin-bottom: 0;
    position: relative;
    padding: 10px 40px; }
    .form-attritubtion p:before {
      content: "—";
      position: absolute;
      left: 15px; }

.pressroom-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px; }
  .pressroom-wrapper:before, .pressroom-wrapper:after {
    content: " ";
    display: table; }
  .pressroom-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .pressroom-wrapper {
      max-width: 60em; } }

.pressroom-header {
  *zoom: 1;
  display: block;
  margin-bottom: 10px; }
  .pressroom-header:before, .pressroom-header:after {
    content: " ";
    display: table; }
  .pressroom-header:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .pressroom-header {
      margin-bottom: 20px; } }

.pressroom-title {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0;
  font-size: 20px;
  font-weight: 400; }

.pressroom-item-title {
  text-transform: uppercase;
  margin: 0;
  font-size: 17px;
  color: #00b4ea;
  font-weight: 400; }

.pressroom-item {
  *zoom: 1;
  display: block;
  margin-bottom: 25px; }
  .pressroom-item:before, .pressroom-item:after {
    content: " ";
    display: table; }
  .pressroom-item:after {
    clear: both; }

.pressroom-itemsecond {
  *zoom: 1;
  display: block;
  margin-bottom: 40px; }
  .pressroom-itemsecond:before, .pressroom-itemsecond:after {
    content: " ";
    display: table; }
  .pressroom-itemsecond:after {
    clear: both; }

.pressroom-image {
  max-width: 100%;
  height: auto; }

.pressroom-side-wrapper {
  height: 40px;
  width: 80px;
  float: left;
  margin: 0 20px 20px 0;
  text-align: center;
  padding: 5px 0 0; }

.pressroom-content-wrapper {
  margin: 0 0 0 100px; }

.pressroom-text {
  margin-bottom: 5px; }

.pressroom-readmore {
  color: #00ac4d;
  -webkit-transition: all 300 ease;
  -moz-transition: all 300 ease;
  transition: all 300 ease; }
  .pressroom-readmore:after {
    content: '\003E';
    position: relative;
    top: 1px; }
  .pressroom-readmore:link, .pressroom-readmore:visited {
    color: #00ac4d; }
  .pressroom-readmore:hover, .pressroom-readmore:active {
    color: #00df64; }

.pressroom-viewall-wrapper {
  *zoom: 1;
  display: block;
  text-align: center; }
  .pressroom-viewall-wrapper:before, .pressroom-viewall-wrapper:after {
    content: " ";
    display: table; }
  .pressroom-viewall-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .pressroom-viewall-wrapper {
      text-align: left; } }

@media screen and (min-width: 960px) {
  .pressroom-viewall {
    margin: 0 0 0 100px; } }

.pressroom-column {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  padding: 0 0 20px;
  margin-bottom: 10px;
  border-bottom: 1px solid #dddddd; }
  .pressroom-column:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .pressroom-column {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%;
      padding: 0 0 60px;
      border-bottom: 0; }
      .pressroom-column:last-child {
        margin-right: 0; } }

.pressroom-column:last-of-type {
  border-bottom: 0; }

.pressroom-datecircle {
  width: 66px;
  height: 66px;
  background: #dddddd;
  border-radius: 50%;
  margin: 0 auto;
  padding: 3px 0 0; }

.pressroom-day {
  display: block;
  line-height: 20px;
  font-size: 22px;
  font-weight: 400; }

.pressroom-month {
  display: block;
  font-size: 17px;
  line-height: 23px;
  text-transform: capitalize; }

.pressroom-year {
  display: block;
  font-size: 11px;
  line-height: 15px; }

.event-wrapper, .event-content-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px; }
  .event-wrapper:before, .event-wrapper:after, .event-content-wrapper:before, .event-content-wrapper:after {
    content: " ";
    display: table; }
  .event-wrapper:after, .event-content-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .event-wrapper, .event-content-wrapper {
      max-width: 60em; } }

.event-webinarlist-wrapper, .event-content {
  *zoom: 1;
  display: block;
  border-bottom: 1px solid #dddddd; }
  .event-webinarlist-wrapper:before, .event-webinarlist-wrapper:after, .event-content:before, .event-content:after {
    content: " ";
    display: table; }
  .event-webinarlist-wrapper:after, .event-content:after {
    clear: both; }

.event-upcoming-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .event-upcoming-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .event-upcoming-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 31.1828%;
      margin-left: 8.60215%; }
      .event-upcoming-wrapper:last-child {
        margin-right: 0; } }

.event-featured-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  padding: 0 0 20px;
  margin-bottom: 20px;
  border-bottom: 1px solid #dddddd; }
  .event-featured-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .event-featured-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .event-featured-wrapper:last-child {
        margin-right: 0; } }

.event-webinar-item {
  margin-bottom: 0;
  padding: 0 0 20px;
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 72.41379%; }
  .event-webinar-item:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .event-webinar-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 82.7957%; }
      .event-webinar-item:last-child {
        margin-right: 0; } }

.event-webinar-image {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 17.24138%;
  margin-bottom: 10px;
  text-align: center; }
  .event-webinar-image:last-child {
    margin-right: 0; }
  .event-webinar-image img {
    max-width: 100%;
    margin: 0 auto; }
  @media screen and (min-width: 960px) {
    .event-webinar-image {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 13.97849%; }
      .event-webinar-image:last-child {
        margin-right: 0; } }

.event-webinar-title {
  font-weight: 400;
  margin-bottom: 20px;
  margin-top: 20px;
  text-transform: uppercase;
  font-size: 25px; }

.event-webinar-item-title {
  color: #037bac;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 20px; }

.event-featured-title {
  text-transform: uppercase;
  margin: 0 0 20px;
  font-size: 20px;
  color: #00ac4d;
  text-align: center; }
  .event-featured-title:after {
    content: '';
    display: block;
    width: 66%;
    margin: 5px auto 5px;
    border-bottom: 1px solid #00ac4d; }

.event-featured-description {
  margin-bottom: 20px; }

.event-featured-link-wrapper {
  text-align: center; }

.event-featured-date {
  font-size: 25px;
  text-align: center;
  display: block;
  margin: 0 0 20px; }

.event-featured-link {
  display: inline-block;
  padding: 10px 25px;
  background: #00ac4d;
  text-align: center;
  text-decoration: none;
  color: white;
  line-height: 20px;
  border-radius: 20px;
  margin: 6px 0 10px;
  text-transform: uppercase;
  font-size: 13px;
  letter-spacing: .18em;
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease;
  line-height: 30px;
  padding: 0 20px; }
  .event-featured-link:visited, .event-featured-link:link {
    background: #00ac4d;
    text-decoration: none;
    color: white; }
  .event-featured-link:hover {
    background: #00c658; }

.event-upcoming-date {
  text-transform: uppercase; }

.event-upcoming-item {
  margin: 0 0 20px; }

.event-upcoming-title {
  font-size: 20px;
  text-align: center; }

.event-webinar-link {
  display: inline-block;
  padding: 10px 25px;
  background: #037bac;
  text-align: center;
  text-decoration: none;
  color: white;
  line-height: 20px;
  border-radius: 20px;
  margin: 6px 0 10px;
  text-transform: uppercase;
  font-size: 13px;
  letter-spacing: .18em;
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease;
  line-height: 30px;
  padding: 0 20px; }
  .event-webinar-link:visited, .event-webinar-link:link {
    background: #037bac;
    text-decoration: none;
    color: white; }
  .event-webinar-link:hover {
    background: #038dc5; }

.event-viewmore-wrapper {
  text-align: right; }

.careers-benefits-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px 0; }
  .careers-benefits-wrapper:before, .careers-benefits-wrapper:after {
    content: " ";
    display: table; }
  .careers-benefits-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .careers-benefits-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .careers-benefits-wrapper {
      padding: 30px 10px 0; } }

.careers-content {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px; }
  .careers-content:before, .careers-content:after {
    content: " ";
    display: table; }
  .careers-content:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .careers-content {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .careers-content {
      padding: 40px 10px 20px; }
      .careers-content ul {
        padding-left: 0; } }

.careers-video-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px; }
  .careers-video-wrapper:before, .careers-video-wrapper:after {
    content: " ";
    display: table; }
  .careers-video-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .careers-video-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .careers-video-wrapper {
      margin-bottom: 10px; } }

.careers-postions-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px; }
  .careers-postions-wrapper:before, .careers-postions-wrapper:after {
    content: " ";
    display: table; }
  .careers-postions-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .careers-postions-wrapper {
      max-width: 60em; } }

.careers-intro-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 30px 10px 20px;
  border-bottom: 1px solid #dddddd; }
  .careers-intro-wrapper:before, .careers-intro-wrapper:after {
    content: " ";
    display: table; }
  .careers-intro-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .careers-intro-wrapper {
      max-width: 60em; } }

@media screen and (min-width: 960px) {
  .careers-main {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 56.98925%; }
    .careers-main:last-child {
      margin-right: 0; } }

@media screen and (min-width: 960px) {
  .careers-sub {
    padding: 0 0 0 40px;
    border-left: 1px solid #dddddd;
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 39.78495%; }
    .careers-sub:last-child {
      margin-right: 0; } }

.careers-image-wrapper img {
  width: 100%;
  height: auto; }
@media screen and (min-width: 960px) {
  .careers-image-wrapper {
    padding: 20px 0 0; } }

.careers-intro-text, .careers-intro-text p {
  text-align: center; }
  @media screen and (min-width: 960px) {
    .careers-intro-text, .careers-intro-text p {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 82.7957%;
      margin-left: 8.60215%;
      font-size: 20px; }
      .careers-intro-text:last-child, .careers-intro-text p:last-child {
        margin-right: 0; } }

.careers-intro-link-wrapper {
  text-align: center; }

.careers-positions {
  background: #f5f6f6;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd; }

.careers-intro-link {
  line-height: 35px;
  padding: 0 30px; }

.careers-title {
  font-size: 25px;
  text-transform: uppercase;
  font-weight: 400; }

.job-item {
  margin-bottom: 10px;
  *zoom: 1;
  display: block; }
  .job-item:before, .job-item:after {
    content: " ";
    display: table; }
  .job-item:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .job-item {
      margin-bottom: 15px; } }

.job-title {
  font-size: 16px; }
  @media screen and (min-width: 960px) {
    .job-title {
      float: left; } }

@media screen and (min-width: 960px) {
  .job-location {
    float: right; } }

.horizontal-seperator {
  border-top: 1px solid #dddddd;
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em; }
  .horizontal-seperator:before, .horizontal-seperator:after {
    content: " ";
    display: table; }
  .horizontal-seperator:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .horizontal-seperator {
      max-width: 60em; } }

.casestudy-metacontent-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px; }
  .casestudy-metacontent-wrapper:before, .casestudy-metacontent-wrapper:after {
    content: " ";
    display: table; }
  .casestudy-metacontent-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .casestudy-metacontent-wrapper {
      max-width: 60em; } }

.casestudy-maincontent-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px; }
  .casestudy-maincontent-wrapper:before, .casestudy-maincontent-wrapper:after {
    content: " ";
    display: table; }
  .casestudy-maincontent-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .casestudy-maincontent-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .casestudy-maincontent-wrapper {
      padding: 20px 10px 30px; } }

.casestudy-image-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  margin-bottom: 10px; }
  .casestudy-image-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .casestudy-image-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 39.78495%; }
      .casestudy-image-wrapper:last-child {
        margin-right: 0; } }

.casestudy-description {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .casestudy-description:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .casestudy-description {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 56.98925%; }
      .casestudy-description:last-child {
        margin-right: 0; } }

.casestudy-quote-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .casestudy-quote-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .casestudy-quote-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 39.78495%; }
      .casestudy-quote-wrapper:last-child {
        margin-right: 0; } }

.casestudy-award-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .casestudy-award-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .casestudy-award-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 56.98925%; }
      .casestudy-award-wrapper:last-child {
        margin-right: 0; } }

.casestudy-metacontent {
  background: #f5f6f6;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd;
  padding: 10px 0; }
  @media screen and (min-width: 960px) {
    .casestudy-metacontent {
      padding: 30px 0; } }

.casestudy-meta-wrapper {
  *zoom: 1;
  margin-bottom: 20px; }
  .casestudy-meta-wrapper:before, .casestudy-meta-wrapper:after {
    content: " ";
    display: table; }
  .casestudy-meta-wrapper:after {
    clear: both; }

.casestudy-description-wrapper {
  padding: 20px 0;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd; }

.casestudy-panel {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%; }
  .casestudy-panel:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .casestudy-panel {
      display: block;
      float: left;
      margin-right: 5.66038%;
      width: 39.62264%; }
      .casestudy-panel:last-child {
        margin-right: 0; } }

.casestudy-award-title {
  text-transform: uppercase; }

.casestudy-award-subtitle {
  text-transform: none;
  display: block;
  font-weight: 300;
  font-size: 16px; }

.casestudy-award-main {
  padding: 0 0 20px;
  margin-bottom: 20px;
  border-bottom: 1px solid #b0b0b0; }

.casestudy-panel {
  background: white;
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.3);
  text-align: center;
  padding: 10px 20px; }

.casestudy-panel-link {
  line-height: 30px;
  padding: 0 30px; }

.casestudy-panel-content {
  margin-bottom: 10px;
  font-size: 14px;
  font-weight: 400;
  line-height: 20px; }

.casestudy-quote-wrapper {
  background: white;
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.3);
  margin-bottom: 20px; }

.casestudy-quote-text {
  padding: 20px; }

.casestudy-quote-attribution {
  background: #037bac;
  padding: 20px;
  text-align: center;
  position: relative; }
  .casestudy-quote-attribution:after {
    content: '';
    display: block;
    height: 0px;
    width: 0px;
    border-top: 15px solid white;
    border-left: 20px solid transparent;
    border-right: 20px solid transparent;
    position: absolute;
    top: 0;
    left: 50%;
    margin-left: -20px; }

.casestudy-quote-name {
  color: white;
  font-size: 18px;
  font-weight: 400;
  display: block;
  margin-bottom: 5px; }

.casestudy-quote-title {
  color: white;
  font-style: italic;
  display: block; }

.casestudy-image-wrapper {
  text-align: center; }

.casestudy-image {
  max-width: 100%;
  height: auto; }

.customer-list-content {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 10px 10px; }
  .customer-list-content:before, .customer-list-content:after {
    content: " ";
    display: table; }
  .customer-list-content:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .customer-list-content {
      max-width: 60em; } }

.customer-list {
  padding: 0;
  margin: 10px 0 0 0;
  font-size: 0;
  min-height: 135px;
  position: relative;
  *zoom: 1; }
  .customer-list:before, .customer-list:after {
    content: " ";
    display: table; }
  .customer-list:after {
    clear: both; }

.customer-list-item {
  padding: 10px 5px;
  list-style: none;
  margin: 0;
  text-align: center;
  width: 50%;
  display: inline-block; }
  @media screen and (min-width: 960px) {
    .customer-list-item {
      width: 33%;
      text-align: left;
      vertical-align: top; } }

.customer-filter {
  display: block;
  list-style: none;
  cursor: pointer; }
  .customer-filter:hover {
    color: #049fde; }
  @media screen and (min-width: 960px) {
    .customer-filter {
      padding: 0 15px;
      float: left;
      border-left: 1px solid #dddddd; }
      .customer-filter:first-child {
        padding-left: 0;
        border-left: 0; } }

.customer-filter-wrapper {
  margin: 0;
  padding: 0;
  *zoom: 1; }
  .customer-filter-wrapper:before, .customer-filter-wrapper:after {
    content: " ";
    display: table; }
  .customer-filter-wrapper:after {
    clear: both; }

.recording-video-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 10px 10px 0; }
  .recording-video-wrapper:before, .recording-video-wrapper:after {
    content: " ";
    display: table; }
  .recording-video-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .recording-video-wrapper {
      max-width: 60em; } }

.recording-content-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px 10px;
  margin-bottom: 20px; }
  .recording-content-wrapper:before, .recording-content-wrapper:after {
    content: " ";
    display: table; }
  .recording-content-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .recording-content-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .recording-content-wrapper {
      padding: 30px 10px 10px;
      margin-bottom: 30px; } }

.recording-slides-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px; }
  .recording-slides-wrapper:before, .recording-slides-wrapper:after {
    content: " ";
    display: table; }
  .recording-slides-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .recording-slides-wrapper {
      max-width: 60em; } }

.recording-subcontent-wrapper {
  border-bottom: 1px solid #dddddd;
  padding: 0 0 10px;
  margin-bottom: 20px; }

.recording-subcontent, .recording-description {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .recording-subcontent:last-child, .recording-description:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .recording-subcontent, .recording-description {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .recording-subcontent:last-child, .recording-description:last-child {
        margin-right: 0; } }

.recording-title {
  font-size: 20px;
  font-weight: 400;
  color: #00b4ea; }

.recording-slides-wrapper {
  text-align: center; }

.recording-slide-link {
  line-height: 35px;
  padding: 0 30px; }

.pricing-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px; }
  .pricing-wrapper:before, .pricing-wrapper:after {
    content: " ";
    display: table; }
  .pricing-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .pricing-wrapper {
      max-width: 60em; } }

.pricing-content {
  background: #f5f6f6;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd; }

.pricing-table {
  margin-bottom: 30px;
  display: none; }
  @media screen and (min-width: 960px) {
    .pricing-table {
      *zoom: 1;
      display: table;
      width: 100%;
      table-layout: fixed; }
      .pricing-table:before, .pricing-table:after {
        content: " ";
        display: table; }
      .pricing-table:after {
        clear: both; } }

.pricing-table-mobile {
  *zoom: 1;
  display: table;
  width: 100%;
  table-layout: fixed; }
  .pricing-table-mobile:before, .pricing-table-mobile:after {
    content: " ";
    display: table; }
  .pricing-table-mobile:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .pricing-table-mobile {
      display: none; } }

.pricing-feature {
  text-align: right;
  color: #037bac;
  font-weight: 400;
  padding: 10px 0;
  display: table-cell;
  padding-right: 3.22581%;
  width: 25.80645%; }
  .pricing-feature:last-child {
    width: 22.58065%;
    padding-right: 0; }

.pricing-row:nth-of-type(4) .pricing-feature {
  padding: 40px 20px 10px; }

.pricing-cell {
  background: white;
  border-left: 20px solid #f5f6f6;
  border-bottom: 1px solid #dddddd;
  text-align: center;
  display: table-cell;
  padding-right: 3.22581%;
  width: 25.80645%;
  padding: 10px; }
  .pricing-cell:last-child {
    width: 22.58065%;
    padding-right: 0; }

.pricing-row:nth-of-type(3) .pricing-feature {
  padding: 30px 5px 10px; }

.pricing-row:nth-of-type(4) .pricing-cell {
  padding: 40px 5px 10px;
  position: relative; }
  .pricing-row:nth-of-type(4) .pricing-cell:before {
    content: ' ';
    display: block;
    width: 100%;
    border-top: 1px solid #dddddd;
    position: absolute;
    left: 0;
    top: 30px; }

@media screen and (min-width: 960px) {
  .pricing-row:nth-of-type(4) .pricing-cell:after {
    content: ' ';
    display: block;
    position: absolute;
    left: 50%;
    width: 0;
    top: 0;
    margin-left: -20px;
    border-top: 15px solid #00b4ea;
    border-left: 20px solid transparent;
    border-right: 20px solid transparent; } }

@media screen and (min-width: 960px) {
  .pricing-row:nth-of-type(4) .pricing-cell:nth-of-type(3):after {
    content: ' ';
    display: block;
    position: absolute;
    left: 50%;
    width: 0;
    top: 0;
    margin-left: -20px;
    border-top: 15px solid #00ac4d;
    border-left: 20px solid transparent;
    border-right: 20px solid transparent; } }

@media screen and (min-width: 960px) {
  .pricing-row:nth-of-type(4) .pricing-cell:nth-of-type(4):after {
    content: ' ';
    display: block;
    position: absolute;
    left: 50%;
    width: 0;
    top: 0;
    margin-left: -20px;
    border-top: 15px solid #00ac4d;
    border-left: 20px solid transparent;
    border-right: 20px solid transparent; } }

.pricing-header-developer {
  padding: 15px 5px;
  border-left: 20px solid #f5f6f6;
  background: #009ecd;
  color: white;
  font-weight: 400;
  text-transform: uppercase;
  font-size: 18px;
  letter-spacing: 0.02;
  position: relative; }

.pricing-header-starter {
  padding: 15px 5px;
  border-left: 20px solid #f5f6f6;
  background: #037bac;
  color: white;
  font-weight: 400;
  text-transform: uppercase;
  font-size: 18px;
  letter-spacing: 0.02;
  position: relative; }

.pricing-header-enterprise {
  padding: 15px 5px;
  border-left: 20px solid #f5f6f6;
  background: #019543;
  color: white;
  font-weight: 400;
  text-transform: uppercase;
  font-size: 18px;
  letter-spacing: 0.02;
  position: relative; }

.pricing-price-developer {
  padding: 15px 5px;
  border-left: 20px solid #f5f6f6;
  color: white;
  background: #00b4ea;
  color: white;
  font-weight: 300;
  position: relative; }

.pricing-price-starter {
  padding: 15px 5px;
  border-left: 20px solid #f5f6f6;
  color: white;
  background: #0097d5;
  color: white;
  font-weight: 300;
  position: relative; }

.pricing-price-enterprise {
  padding: 15px 5px;
  border-left: 20px solid #f5f6f6;
  color: white;
  background: #00ac4d;
  color: white;
  font-weight: 300;
  position: relative; }

.pricing-smallprint-wrapper {
  *zoom: 1;
  display: block; }
  .pricing-smallprint-wrapper:before, .pricing-smallprint-wrapper:after {
    content: " ";
    display: table; }
  .pricing-smallprint-wrapper:after {
    clear: both; }

.pricing-smallprint {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  margin-bottom: 20px; }
  .pricing-smallprint:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .pricing-smallprint {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 74.19355%;
      margin-left: 25.80645%;
      margin-bottom: 40px; }
      .pricing-smallprint:last-child {
        margin-right: 0; } }

.pricing-smallprint p, .pricing-smallprint li {
  font-size: 13px;
  line-height: 15px;
  margin-bottom: 10px; }

.pricing-link {
  padding: 0 10px;
  display: block;
  width: 100%; }
  @media screen and (min-width: 960px) {
    .pricing-link {
      display: table-cell; } }

.pricing-calltoaction {
  line-height: 20px;
  padding: 10px 30px;
  margin-bottom: 20px; }

.content1-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px; }
  .content1-wrapper:before, .content1-wrapper:after {
    content: " ";
    display: table; }
  .content1-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .content1-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .content1-wrapper {
      padding: 30px 10px; } }

.content1-item {
  *zoom: 1;
  display: block;
  padding: 0 0 30px;
  margin: 0 0 30px;
  border-bottom: 1px solid #dddddd; }
  .content1-item:before, .content1-item:after {
    content: " ";
    display: table; }
  .content1-item:after {
    clear: both; }
  .content1-item:last-child {
    border-bottom: 0;
    margin-bottom: 0;
    padding: 0; }

@media screen and (min-width: 960px) {
  .casestudy-individual .content1-item-content {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 65.5914%;
    float: right; }
    .casestudy-individual .content1-item-content:last-child {
      margin-right: 0; } }
@media screen and (min-width: 960px) {
  .casestudy-individual .content1-item-imagewrapper {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 31.1828%;
    float: right; }
    .casestudy-individual .content1-item-imagewrapper:last-child {
      margin-right: 0; } }
.casestudy-individual .content1-item-image img {
  max-width: 80%; }

.content1-item-title {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  @media screen and (min-width: 960px) {
    .content1-item-title {
      font-size: 20px;
      line-height: 25px; } }

.content1-item-subtitle {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0;
  font-size: 17px;
  font-weight: 300; }

.content1-item-header {
  margin: 0 0 5px; }

@media screen and (min-width: 960px) {
  .content1-item-content {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 48.3871%; }
    .content1-item-content:last-child {
      margin-right: 0; } }

@media screen and (min-width: 960px) {
  .content1-item:nth-of-type(2n) .content1-item-content {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 48.3871%;
    margin-right: 0;
    float: right; }
    .content1-item:nth-of-type(2n) .content1-item-content:last-child {
      margin-right: 0; } }

.content1-item-imagewrapper {
  text-align: center; }
  @media screen and (min-width: 960px) {
    .content1-item-imagewrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .content1-item-imagewrapper:last-child {
        margin-right: 0; } }

.content1-item-image, .content1-item-image img {
  max-width: 100%;
  height: auto;
  margin: 0 auto; }

.content1-item-description {
  font-size: 14px;
  line-height: 20px;
  font-weight: 300;
  letter-spacing: .06em; }
  @media screen and (min-width: 960px) {
    .content1-item-description {
      font-size: 16px;
      line-height: 25px; } }

.content2-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px; }
  .content2-wrapper:before, .content2-wrapper:after {
    content: " ";
    display: table; }
  .content2-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .content2-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .content2-wrapper {
      padding: 30px 10px; } }

.content2-item {
  *zoom: 1;
  display: block;
  margin: 0 0 15px; }
  .content2-item:before, .content2-item:after {
    content: " ";
    display: table; }
  .content2-item:after {
    clear: both; }
  .content2-item:last-child {
    margin-bottom: 0;
    padding: 0; }

@media screen and (min-width: 960px) {
  .content2-item-wrapper {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 100%; }
    .content2-item-wrapper:last-child {
      margin-right: 0; } }

.content2-item-title {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  @media screen and (min-width: 960px) {
    .content2-item-title {
      font-size: 20px; } }

.content2-item-subtitle {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0;
  font-size: 17px;
  font-weight: 300; }

.content2-item-description {
  font-size: 14px;
  line-height: 20px;
  font-weight: 300;
  letter-spacing: .06em; }
  @media screen and (min-width: 960px) {
    .content2-item-description {
      font-size: 16px;
      line-height: 25px; } }

.content2-item-link {
  font-weight: 400;
  text-transform: uppercase;
  font-size: 18px;
  display: inline-block;
  margin-bottom: 15px; }
  .content2-item-link:after {
    content: " >"; }

.content3-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px 0; }
  .content3-wrapper:before, .content3-wrapper:after {
    content: " ";
    display: table; }
  .content3-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .content3-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .content3-wrapper {
      padding: 30px 10px 0; } }

.content3-item {
  *zoom: 1;
  display: block;
  margin: 0 0 15px; }
  .content3-item:before, .content3-item:after {
    content: " ";
    display: table; }
  .content3-item:after {
    clear: both; }

.content3-item-date {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 17.24138%; }
  .content3-item-date:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .content3-item-date {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 22.58065%; }
      .content3-item-date:last-child {
        margin-right: 0; } }

@media screen and (min-width: 960px) {
  .content3-item-wrapper {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 74.19355%;
    margin-bottom: 20px; }
    .content3-item-wrapper:last-child {
      margin-right: 0; } }

@media screen and (min-width: 960px) {
  .content3-subitem-wrapper {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 22.58065%;
    margin-bottom: 10px; }
    .content3-subitem-wrapper:last-child {
      margin-right: 0; } }

.content3-image {
  max-width: 100%;
  height: auto;
  margin-bottom: 20px;
  box-shadow: 0 0 5px 0 rgba(0, 0, 0, 0.3); }

.content3-item-title {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 20px; }

.content3-item-subtitle {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0;
  font-size: 17px;
  font-weight: 300; }

.content3-item-description {
  font-size: 14px;
  line-height: 20px;
  font-weight: 300;
  letter-spacing: .06em; }
  @media screen and (min-width: 960px) {
    .content3-item-description {
      font-size: 16px;
      line-height: 25px; } }

.content3-item-link {
  font-weight: 400;
  text-transform: uppercase;
  font-size: 18px;
  display: inline-block;
  margin-bottom: 15px; }
  .content3-item-link:after {
    content: " >"; }

.flexcontent3-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 10px 10px;
  border-bottom: 1px solid #dddddd; }
  .flexcontent3-wrapper:before, .flexcontent3-wrapper:after {
    content: " ";
    display: table; }
  .flexcontent3-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .flexcontent3-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .flexcontent3-wrapper {
      padding: 20px 10px; } }

.flexcontent3-item {
  *zoom: 1;
  display: block; }
  .flexcontent3-item:before, .flexcontent3-item:after {
    content: " ";
    display: table; }
  .flexcontent3-item:after {
    clear: both; }

.flexcontent3-item-wrapper {
  margin-bottom: 10px; }
  @media screen and (min-width: 960px) {
    .flexcontent3-item-wrapper {
      margin-bottom: 15px;
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 74.19355%; }
      .flexcontent3-item-wrapper:last-child {
        margin-right: 0; } }

.flexcontent3-item-subwrapper {
  margin-bottom: 10px; }
  @media screen and (min-width: 960px) {
    .flexcontent3-item-subwrapper {
      margin-bottom: 15px;
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 22.58065%; }
      .flexcontent3-item-subwrapper:last-child {
        margin-right: 0; } }

.flexcontent3-header {
  margin-bottom: 10px; }
  @media screen and (min-width: 960px) {
    .flexcontent3-header {
      margin-bottom: 15px; } }

.flexcontent3-image-wrapper {
  margin-bottom: 10px;
  text-align: center; }
  @media screen and (min-width: 960px) {
    .flexcontent3-image-wrapper {
      margin-bottom: 15px; } }

.flexcontent3-image {
  max-width: 100%; }

.flexcontent3-item-title {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  @media screen and (min-width: 960px) {
    .flexcontent3-item-title {
      font-size: 20px; } }

.flexcontent3-item-subtitle {
  color: #00b4ea;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 15px;
  line-height: 20px;
  font-weight: 300; }
  @media screen and (min-width: 960px) {
    .flexcontent3-item-subtitle {
      font-size: 16px; } }

.flexcontent-subwrapper-title {
  font-weight: 400;
  margin-bottom: 5px;
  display: block; }

.flexcontent3-person-name {
  font-weight: 400;
  font-size: 14px; }

.flexcontent3-person-title {
  font-weight: 300;
  font-style: italic; }

.flexcontent3-person-image {
  width: 104px;
  height: auto;
  border: 2px solid #dddddd; }

.flexcontent3-person-image-wrapper {
  width: 50%;
  padding: 0 5px 0 0;
  float: left; }
  .flexcontent3-person-image-wrapper:nth-child(2n) {
    padding: 0 0 0 5px; }

.flexcontent3-person-image-container {
  *zoom: 1;
  margin-bottom: 5px; }
  .flexcontent3-person-image-container:before, .flexcontent3-person-image-container:after {
    content: " ";
    display: table; }
  .flexcontent3-person-image-container:after {
    clear: both; }

@media screen and (min-width: 960px) {
  .content4-wordswrapper {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 65.5914%; }
    .content4-wordswrapper:last-child {
      margin-right: 0; } }

.content4-wrapper {
  padding: 20px 10px; }

.content4-sideimagewrapper {
  display: none; }
  @media screen and (min-width: 960px) {
    .content4-sideimagewrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 31.1828%;
      margin-bottom: 10px; }
      .content4-sideimagewrapper:last-child {
        margin-right: 0; } }

.content5-wrapper {
  padding: 20px 10px; }

.content5-item {
  margin-bottom: 10px; }
  @media screen and (min-width: 960px) {
    .content5-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%;
      margin-bottom: 20px; }
      .content5-item:last-child {
        margin-right: 0; }
      .content5-item:nth-child(2n) {
        margin-right: 0; } }

.content5-item-title {
  font-size: 16px;
  line-height: 20px;
  font-weight: 400;
  color: #037bac;
  text-transform: uppercase; }
  .content5-item-title:after {
    content: ' ';
    display: block;
    width: 100%;
    border-bottom: 1px solid #037bac;
    margin: 5px 0;
    max-width: 66%; }
  @media screen and (min-width: 960px) {
    .content5-item-title {
      font-size: 18px; } }

.content6-item-wrapper {
  padding: 10px 0; }
  @media screen and (min-width: 960px) {
    .content6-item-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 65.5914%;
      padding: 20px 0; }
      .content6-item-wrapper:last-child {
        margin-right: 0; } }

.content6-item {
  padding: 10px 0; }

.content6-item-subwrapper {
  text-align: center; }
  @media screen and (min-width: 960px) {
    .content6-item-subwrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 31.1828%;
      margin-bottom: 10px; }
      .content6-item-subwrapper:last-child {
        margin-right: 0; } }

.content6-image {
  max-width: 75%;
  max-height: 240px; }
  @media screen and (min-width: 960px) {
    .content6-image {
      max-height: 320px; } }

.menu-skybox-container {
  *zoom: 1;
  display: block; }
  .menu-skybox-container:before, .menu-skybox-container:after {
    content: " ";
    display: table; }
  .menu-skybox-container:after {
    clear: both; }

.main-skybox-navlist {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 5px;
  background: white;
  padding: 0;
  text-align: center;
  margin-bottom: 0; }
  .main-skybox-navlist:before, .main-skybox-navlist:after {
    content: " ";
    display: table; }
  .main-skybox-navlist:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .main-skybox-navlist {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .main-skybox-navlist {
      text-align: right;
      padding: 0 10px; } }
  .main-skybox-navlist .menu-item {
    display: inline-block;
    list-style: none;
    padding: 5px 2px 0;
    font-size: 14px;
    line-height: 20px; }
    @media screen and (min-width: 960px) {
      .main-skybox-navlist .menu-item {
        padding: 10px 0 0 10px; } }

.main-header {
  background: #037bac;
  z-index: 9999;
  position: fixed;
  width: 100%;
  top: 0;
  left: 0; }

@media screen and (min-width: 960px) {
  .main-header-wrapper {
    *zoom: 1;
    max-width: 60em;
    margin-left: auto;
    margin-right: auto;
    max-width: 32.5em;
    padding: 0 10px; }
    .main-header-wrapper:before, .main-header-wrapper:after {
      content: " ";
      display: table; }
    .main-header-wrapper:after {
      clear: both; } }
  @media screen and (min-width: 960px) and (min-width: 960px) {
    .main-header-wrapper {
      max-width: 60em; } }

.main-header-logo-wrapper {
  width: 50%;
  float: left;
  padding: 0 5px; }
  @media screen and (min-width: 960px) {
    .main-header-logo-wrapper {
      width: auto; } }

.main-header-logo-link {
  display: block; }

.main-header-toggle-wrapper {
  width: 50%;
  float: left;
  padding: 0 10px 0 0;
  text-align: right; }
  @media screen and (min-width: 960px) {
    .main-header-toggle-wrapper {
      display: none; } }

.main-header-subcontent {
  *zoom: 1;
  height: 50px;
  overflow: hidden; }
  .main-header-subcontent:before, .main-header-subcontent:after {
    content: " ";
    display: table; }
  .main-header-subcontent:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .main-header-subcontent {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 22.58065%; }
      .main-header-subcontent:last-child {
        margin-right: 0; } }

.main-header-toggle {
  color: white;
  display: inline-block;
  line-height: 50px; }
  .main-header-toggle:link, .main-header-toggle:visited {
    color: white; }

.main-header-logo:before {
  display: inline-block;
  font-size: 164px;
  line-height: 50px;
  color: white; }

@media screen and (min-width: 960px) {
  .menu-header-menu-container {
    display: block;
    float: left;
    margin-right: 3.22581%;
    width: 74.19355%; }
    .menu-header-menu-container:last-child {
      margin-right: 0; } }

.main-header-navlist {
  padding: 0;
  text-align: center;
  margin-bottom: 0;
  position: absolute;
  width: 100%;
  z-index: 9999;
  display: none;
  -webkit-transition: max-height 0.6s ease-out;
  -moz-transition: max-height 0.6s ease-out;
  transition: max-height 0.6s ease-out; }
  @media screen and (min-width: 960px) {
    .main-header-navlist {
      text-align: right;
      height: 50px;
      position: static;
      width: auto;
      display: block !important; } }

.main-header-navlist .sub-menu {
  margin-bottom: 0;
  padding: 0;
  background: #024561;
  min-width: 100%;
  display: none;
  -webkit-transition: background 0.3s ease-out;
  -moz-transition: background 0.3s ease-out;
  transition: background 0.3s ease-out; }
  .main-header-navlist .sub-menu:before, .main-header-navlist .sub-menu:after {
    content: " ";
    display: table; }
  .main-header-navlist .sub-menu:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .main-header-navlist .sub-menu {
      position: absolute;
      display: none !important;
      z-index: 9999; } }

@media screen and (min-width: 960px) {
  .main-header-navlist > .menu-item:hover > .sub-menu {
    display: block !important; } }

.main-header-navlist .sub-menu > .menu-item {
  background: #02577a;
  width: 50%;
  float: left;
  font-size: 14px; }
  @media screen and (min-width: 960px) {
    .main-header-navlist .sub-menu > .menu-item {
      width: auto;
      float: none;
      display: block;
      text-align: left;
      min-width: 160px; } }

.main-header-navlist .sub-menu .menu-item a {
  display: block;
  padding: 10px 5px;
  color: white;
  background: #02577a;
  box-shadow: inset 0 0 1px 0 #024561; }
  .main-header-navlist .sub-menu .menu-item a:link, .main-header-navlist .sub-menu .menu-item a:visited {
    color: white;
    background: #02577a; }
  .main-header-navlist .sub-menu .menu-item a:hover {
    background: #037bac; }
  .main-header-navlist .sub-menu .menu-item a:active {
    background: #024561; }
  @media screen and (min-width: 960px) {
    .main-header-navlist .sub-menu .menu-item a {
      padding: 10px 15px; } }

.main-header-navlist .menu-item {
  background: #036993;
  list-style: none;
  margin-bottom: 0;
  position: relative; }
  .main-header-navlist .menu-item a {
    display: block;
    padding: 10px 5px;
    color: white;
    background: #036993;
    box-shadow: inset 0 0 1px 0 #024561;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis; }
    .main-header-navlist .menu-item a:link, .main-header-navlist .menu-item a:visited {
      color: white;
      background: #036993; }
    .main-header-navlist .menu-item a:hover {
      background: #037bac; }
    .main-header-navlist .menu-item a:active {
      background: #02577a; }
  @media screen and (min-width: 960px) {
    .main-header-navlist .menu-item {
      background: none;
      display: inline-block;
      text-align: center; }
      .main-header-navlist .menu-item a {
        display: block;
        background: none;
        box-shadow: none;
        padding: 15px 8px; }
        .main-header-navlist .menu-item a:link, .main-header-navlist .menu-item a:visited {
          background: none; }
        .main-header-navlist .menu-item a:hover {
          background: #038dc5; }
        .main-header-navlist .menu-item a:active {
          background: #02577a; } }

.main-header-navlist > .menu-item:last-child a {
  display: inline-block;
  padding: 10px 25px;
  background: #00ac4d;
  text-align: center;
  text-decoration: none;
  color: white;
  line-height: 20px;
  border-radius: 20px;
  margin: 6px 0 10px;
  text-transform: uppercase;
  font-size: 13px;
  letter-spacing: .18em;
  font-weight: 700;
  overflow: hidden;
  text-overflow: ellipsis;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease;
  padding: 0 15px;
  line-height: 30px;
  text-transform: none;
  font-weight: 300;
  margin-right: 0;
  margin-left: 0; }
  .main-header-navlist > .menu-item:last-child a:visited, .main-header-navlist > .menu-item:last-child a:link {
    background: #00ac4d;
    text-decoration: none;
    color: white; }
  .main-header-navlist > .menu-item:last-child a:hover {
    background: #00c658; }

.main-header.mw-new-new {
  background: #fff; }
  .main-header.mw-new-new .main-header-subcontent {
    height: auto; }
  .main-header.mw-new-new .main-header-logo-wrapper {
    padding: 15px 0 15px 5px; }
    .main-header.mw-new-new .main-header-logo-wrapper .main-header-logo {
      background: url(styles/logo.png) no-repeat;
      width: 164px;
      height: 20px;
      display: block; }
      .main-header.mw-new-new .main-header-logo-wrapper .main-header-logo:before {
        display: none;
        font-size: initial;
        line-height: initial; }
  .main-header.mw-new-new .main-header-navlist > .menu-item {
    border-bottom: 1px solid #ccc;
    background: #fff; }
    .main-header.mw-new-new .main-header-navlist > .menu-item > a {
      background: #fff;
      color: #000;
      box-shadow: none;
      font-weight: 400; }
    .main-header.mw-new-new .main-header-navlist > .menu-item:first-child {
      border-top: 1px solid #ccc; }
    .main-header.mw-new-new .main-header-navlist > .menu-item:last-child > a {
      background: #cc3;
      padding: .75rem 1.25rem;
      line-height: initial;
      letter-spacing: initial;
      border-radius: 0;
      font-weight: 700;
      text-transform: uppercase;
      font-size: .875rem;
      margin: 5px 0 0 0; }
  .main-header.mw-new-new .main-header-toggle-wrapper > a {
    color: #000;
    font-weight: 400; }
  @media screen and (min-width: 960px) {
    .main-header.mw-new-new {
      line-height: initial;
      padding: 3rem 0 1.5rem;
      border-top: .5rem solid #09c;
      background: #fff; }
      .main-header.mw-new-new .main-header-wrapper {
        max-width: 74rem;
        padding: 0 3.5rem;
        position: relative; }
      .main-header.mw-new-new .menu-header-menu-container {
        float: right;
        margin-right: 0;
        display: inline;
        position: absolute;
        right: 0.5rem;
        top: -0.5rem;
        font-size: 1rem;
        line-height: 1;
        font-style: normal;
        overflow: visible; }
      .main-header.mw-new-new .main-header-logo-wrapper {
        padding: 0; }
      .main-header.mw-new-new .main-header-navlist {
        height: auto;
        line-height: 1em; }
        .main-header.mw-new-new .main-header-navlist > .menu-item {
          margin-right: 2.5rem;
          position: relative;
          vertical-align: middle;
          border: none; }
          .main-header.mw-new-new .main-header-navlist > .menu-item > a {
            color: #000;
            padding: 0;
            font-size: 1rem;
            font-weight: 400; }
            .main-header.mw-new-new .main-header-navlist > .menu-item > a:hover {
              background: none; }
          .main-header.mw-new-new .main-header-navlist > .menu-item:first-child {
            border: 0; }
          .main-header.mw-new-new .main-header-navlist > .menu-item:last-child a {
            margin: 0; }
          .main-header.mw-new-new .main-header-navlist > .menu-item:hover {
            background: none; }
          .main-header.mw-new-new .main-header-navlist > .menu-item > .sub-menu {
            left: -15px;
            padding-top: 1.45em;
            background: transparent; } }

.features2 {
  *zoom: 1;
  display: block; }
  .features2:before, .features2:after {
    content: " ";
    display: table; }
  .features2:after {
    clear: both; }

.features2-header {
  background-color: white; }

.features2-heading {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 15px 10px;
  text-align: center;
  text-transform: uppercase;
  font-weight: 400;
  margin-bottom: 0;
  font-size: 25px; }
  .features2-heading:before, .features2-heading:after {
    content: " ";
    display: table; }
  .features2-heading:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .features2-heading {
      max-width: 60em; } }

.features2-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 25px 10px 15px;
  margin: 0 auto; }
  .features2-wrapper:before, .features2-wrapper:after {
    content: " ";
    display: table; }
  .features2-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .features2-wrapper {
      max-width: 60em; } }

.feature2-item {
  padding: 15px 25px;
  margin: 0 auto 20px;
  box-shadow: 0px 0px 3px rgba(0, 0, 0, 0.3);
  background: white;
  max-width: 350px;
  list-style: none; }
  .feature2-item:nth-of-type(2n) .feature2-item-heading, .feature2-item:nth-of-type(2n) .feature2-item-iconwrapper {
    color: #00ac4d; }
  .feature2-item:nth-of-type(2n) .feature2-item-link {
    line-height: 35px;
    min-width: 66%; }
  .feature2-item:nth-of-type(3n) .feature2-item-heading, .feature2-item:nth-of-type(3n) .feature2-item-iconwrapper {
    color: #037bac; }
  .feature2-item:nth-of-type(3n) .feature2-item-link {
    line-height: 35px;
    min-width: 66%; }
  .feature2-item:nth-of-type(4n) .feature2-item-heading, .feature2-item:nth-of-type(4n) .feature2-item-iconwrapper {
    color: #00b4ea; }
  .feature2-item:nth-of-type(4n) .feature2-item-link {
    line-height: 35px;
    min-width: 66%; }
  @media screen and (min-width: 960px) {
    .feature2-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%;
      max-width: none; }
      .feature2-item:last-child {
        margin-right: 0; }
      .feature2-item:nth-child(2n) {
        margin-right: 0; }
      .feature2-item:nth-child(2n+1) {
        clear: left; } }

.feature2-item-heading {
  text-align: center;
  text-transform: uppercase;
  color: #00b4ea;
  margin: 0 0 5px;
  font-size: 20px;
  line-height: 25px; }

.feature2-item-subheading {
  display: block; }

.feature2-item-content {
  text-align: center;
  font-weight: 300;
  font-size: 18px;
  margin-bottom: 5px; }

.feature2-item-link-wrapper {
  text-align: center; }

.feature2-item-link {
  line-height: 35px;
  min-width: 66%; }

.feature2-item-iconwrapper {
  text-align: center;
  font-size: 54px;
  margin: 0 0 10px;
  color: #00b4ea; }

.main-footer {
  background: #037bac; }

.main-footer-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 20px 10px;
  *zoom: 1;
  display: block; }
  .main-footer-wrapper:before, .main-footer-wrapper:after {
    content: " ";
    display: table; }
  .main-footer-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .main-footer-wrapper {
      max-width: 60em; } }
  .main-footer-wrapper:before, .main-footer-wrapper:after {
    content: " ";
    display: table; }
  .main-footer-wrapper:after {
    clear: both; }

@media screen and (min-width: 960px) {
  .menu-footer-menu-container {
    display: block;
    float: right;
    margin-left: 3.22581%;
    width: 56.98925%; }
    .menu-footer-menu-container:last-child {
      margin-left: 0; } }

@media screen and (min-width: 960px) {
  .main-footer-subcontent {
    display: block;
    float: right;
    margin-left: 3.22581%;
    width: 22.58065%; }
    .main-footer-subcontent:last-child {
      margin-left: 0; } }

.main-footer-logo-wrapper {
  height: 45px;
  overflow: hidden; }

.footer-gartner {
  background-image: url(data:image/png;base64, );
  background-size: contain;
  background-position: top center;
  background-repeat: no-repeat;
  display: none;
  height: 80px;
  width: 100%;
  margin-bottom: 20px; }
  @media screen and (min-width: 960px) {
    .footer-gartner {
      display: block;
      float: right;
      margin-left: 3.22581%;
      width: 13.97849%;
      height: 160px;
      margin-bottom: 0; }
      .footer-gartner:last-child {
        margin-left: 0; } }

.main-footer-header {
  background: #037bac; }

.main-footer-headerwrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 3px 10px 0;
  overflow: hidden;
  height: 40px; }
  .main-footer-headerwrapper:before, .main-footer-headerwrapper:after {
    content: " ";
    display: table; }
  .main-footer-headerwrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .main-footer-headerwrapper {
      max-width: 60em; } }

.main-footer-headerlogo {
  color: white; }
  .main-footer-headerlogo:before {
    font-size: 156px;
    display: inline-block;
    line-height: 30px; }

.main-footer-navlist .menu-item {
  padding: 0;
  margin: 0 0 5px;
  list-style: none; }
  .main-footer-navlist .menu-item > a, .main-footer-navlist .menu-item > a:visited, .main-footer-navlist .menu-item > a:link {
    color: white;
    font-weight: 300; }
  .main-footer-navlist .menu-item > a:hover, .main-footer-navlist .menu-item > a:active {
    opacity: .6; }

.main-footer-navlist > .menu-item {
  margin: 0 0 15px;
  float: right;
  width: 50%; }
  @media screen and (min-width: 960px) {
    .main-footer-navlist > .menu-item {
      float: none;
      display: inline-block;
      width: auto;
      padding: 0 0 0 30px;
      position: relative; } }
  .main-footer-navlist > .menu-item > a, .main-footer-navlist > .menu-item > a:visited, .main-footer-navlist > .menu-item > a:link {
    text-transform: uppercase;
    color: white;
    font-weight: 400;
    margin-bottom: 10px;
    cursor: default; }
  .main-footer-navlist > .menu-item > a:hover, .main-footer-navlist > .menu-item a:active {
    color: white;
    opacity: 1; }

.main-footer-navlist > .menu-item:nth-child(1) {
  float: left; }
  @media screen and (min-width: 960px) {
    .main-footer-navlist > .menu-item:nth-child(1) {
      float: none; } }

.main-footer-navlist, .main-footer-navlist .sub-menu {
  padding: 0;
  margin: 0;
  list-style: none; }

.main-footer-navlist {
  margin-bottom: 25px;
  *zoom: 1; }
  .main-footer-navlist:before, .main-footer-navlist:after {
    content: " ";
    display: table; }
  .main-footer-navlist:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .main-footer-navlist {
      text-align: right;
      min-height: 160px; } }

@media screen and (min-width: 960px) {
  .main-footer-navlist .sub-menu {
    position: absolute;
    top: 30px; } }

.main-footer-navlist .sub-menu .menu-item {
  font-size: 14px;
  text-align: left; }

.main-footer-address {
  margin: 0 0 10px;
  text-align: center; }
  @media screen and (min-width: 960px) {
    .main-footer-address {
      text-align: left; } }

.main-footer-addressstreet {
  color: white;
  margin: 0;
  font-weight: 300;
  font-size: 9px;
  line-height: 15px; }
  @media screen and (min-width: 960px) {
    .main-footer-addressstreet {
      font-size: 12px;
      line-height: 20px; } }

.main-footer-content {
  *zoom: 1;
  display: block; }
  .main-footer-content:before, .main-footer-content:after {
    content: " ";
    display: table; }
  .main-footer-content:after {
    clear: both; }

.main-footer-copyright {
  font-size: 9px;
  letter-spacing: .1em;
  line-height: 15px;
  text-align: center;
  color: white; }
  @media screen and (min-width: 960px) {
    .main-footer-copyright {
      *zoom: 1;
      display: block;
      font-size: 12px;
      line-height: 20px; }
      .main-footer-copyright:before, .main-footer-copyright:after {
        content: " ";
        display: table; }
      .main-footer-copyright:after {
        clear: both; } }
  .main-footer-copyright a, .main-footer-copyright a:visited, .main-footer-copyright a:link {
    color: white;
    font-weight: 300; }
  .main-footer-copyright a:hover, .main-footer-copyright a:active {
    opacity: .6; }

.main-footer-sociallist {
  padding: 0;
  margin: 0 0 10px;
  text-align: center; }
  @media screen and (min-width: 960px) {
    .main-footer-sociallist {
      text-align: left;
      margin: 0 0 15px; } }

.main-footer-social-item {
  list-style: none;
  display: inline-block;
  font-size: 25px; }
  @media screen and (min-width: 960px) {
    .main-footer-social-item {
      font-size: 30px;
      margin: 0 5px 0 0; } }
  .main-footer-social-item > a, .main-footer-social-item > a:visited, .main-footer-social-item > a:link {
    color: white; }
  .main-footer-social-item > a:hover, .main-footer-social-item > a:active {
    opacity: .6; }

.footer-sociallink {
  display: block; }

.blog-mainheader {
  width: 100%;
  background: #00b4ea; }

.blog-mainheader-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px;
  overflow: hidden; }
  .blog-mainheader-wrapper:before, .blog-mainheader-wrapper:after {
    content: " ";
    display: table; }
  .blog-mainheader-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-mainheader-wrapper {
      max-width: 60em; } }

.blog-category-wrapper {
  padding: 20px 0 0;
  text-transform: capitalize; }
  @media screen and (min-width: 960px) {
    .blog-category-wrapper {
      padding: 0 0 20px; } }

.blog-logo {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  display: block;
  font-style: italic;
  text-transform: uppercase;
  color: white;
  font-size: 12px;
  font-weight: 700;
  letter-spacing: 0.2em;
  text-align: left; }
  .blog-logo:last-child {
    margin-right: 0; }
  .blog-logo:visited, .blog-logo:link {
    color: white; }
  .blog-logo:before {
    display: block;
    font-size: 184px;
    line-height: 50px;
    text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3); }
  @media screen and (min-width: 960px) {
    .blog-logo {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 31.1828%; }
      .blog-logo:last-child {
        margin-right: 0; } }

.blog-companysitewrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  text-align: right; }
  .blog-companysitewrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-companysitewrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 22.58065%;
      margin-left: 43.01075%;
      text-align: left; }
      .blog-companysitewrapper:last-child {
        margin-right: 0; } }

.blog-companysite, .blog-companysite:link, .blog-companysite:visited {
  color: white;
  text-transform: uppercase;
  line-height: 50px;
  font-size: 12px; }
  @media screen and (min-width: 960px) {
    .blog-companysite, .blog-companysite:link, .blog-companysite:visited {
      font-size: 16px; } }

.blog-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 30px 10px;
  position: relative; }
  .blog-wrapper:before, .blog-wrapper:after {
    content: " ";
    display: table; }
  .blog-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .blog-wrapper {
      padding: 120px 10px 0; } }

.blog-main-content {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .blog-main-content:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-main-content {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 74.19355%;
      padding: 0 10px 0 0; }
      .blog-main-content:last-child {
        margin-right: 0; } }

.blog-mainfooter {
  width: 100%;
  padding: 10px 10px;
  background: #00b4ea;
  height: 60px; }

.blog-mainfootercontent {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  text-align: center;
  margin-bottom: 0;
  font-size: 9px;
  line-height: 20px;
  color: white; }
  .blog-mainfootercontent:before, .blog-mainfootercontent:after {
    content: " ";
    display: table; }
  .blog-mainfootercontent:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-mainfootercontent {
      max-width: 60em; } }
  .blog-mainfootercontent a, .blog-mainfootercontent a:link, .blog-mainfootercontent a:visited {
    color: white; }
  .blog-mainfootercontent a:hover, .blog-mainfootercontent a:active {
    opacity: .8; }

.blog-controls {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  margin-bottom: 10px;
  padding: 0 10px; }
  .blog-controls:before, .blog-controls:after {
    content: " ";
    display: table; }
  .blog-controls:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-controls {
      max-width: 60em; } }

.blog-controllist {
  padding: 0 10px;
  margin: 0;
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .blog-controllist:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-controllist {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 56.98925%;
      margin-left: 17.2043%;
      padding: 0 15px 0 0; }
      .blog-controllist:last-child {
        margin-right: 0; } }

.blog-control {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  padding: 0;
  font-size: 12px; }
  .blog-control:last-child {
    margin-right: 0; }
  .blog-control:nth-of-type(2) {
    text-align: right; }
  .blog-control a, .blog-control a:link, .blog-control a:visited {
    line-height: 45px;
    text-transform: uppercase; }
  @media screen and (min-width: 960px) {
    .blog-control {
      display: block;
      float: left;
      margin-right: 5.66038%;
      width: 39.62264%;
      font-size: 14px; }
      .blog-control:last-child {
        margin-right: 0; }
      .blog-control:nth-of-type(2) {
        text-align: right;
        display: block;
        float: left;
        margin-right: 5.66038%;
        width: 54.71698%; }
        .blog-control:nth-of-type(2):last-child {
          margin-right: 0; } }

.blog-sidebar {
  display: none; }
  @media screen and (min-width: 960px) {
    .blog-sidebar {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 22.58065%; }
      .blog-sidebar:last-child {
        margin-right: 0; } }

.blog-headerimage {
  height: auto;
  margin: 0 auto 10px; }

.blog-share {
  margin-top: 8px;
  float: right; }
  @media screen and (min-width: 960px) {
    .blog-share {
      float: left; } }

.blog-share-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  line-height: 45px;
  text-align: right;
  padding: 0;
  margin-bottom: 0; }
  .blog-share-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-share-wrapper {
      display: block;
      float: left;
      margin-right: 23.07692%;
      width: 100%;
      line-height: 30px;
      text-align: left;
      text-align: center; }
      .blog-share-wrapper:last-child {
        margin-right: 0; } }

.blog-share-icon {
  font-size: 26px;
  margin: 0;
  display: inline-block;
  list-style: none; }
  .blog-share-icon a {
    display: block; }
  @media screen and (min-width: 960px) {
    .blog-share-icon {
      font-size: 28px; } }

.blog-part {
  *zoom: 1;
  display: block;
  margin-bottom: 20px; }
  .blog-part:before, .blog-part:after {
    content: " ";
    display: table; }
  .blog-part:after {
    clear: both; }
  .blog-part:last-child {
    margin-bottom: 0; }
  @media screen and (min-width: 960px) {
    .blog-part {
      margin-bottom: 60px; } }

.blog-header {
  *zoom: 1;
  display: block; }
  .blog-header:before, .blog-header:after {
    content: " ";
    display: table; }
  .blog-header:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-header {
      margin-bottom: 10px; } }

.blog-subtitle {
  color: #747474;
  font-weight: 400; }

.blog-headerimage {
  max-width: 100%;
  display: block;
  margin: 0 auto 10px; }

.blog-content, .blog-excerpt {
  *zoom: 1;
  display: block;
  margin: 0 0 10px; }
  .blog-content:before, .blog-content:after, .blog-excerpt:before, .blog-excerpt:after {
    content: " ";
    display: table; }
  .blog-content:after, .blog-excerpt:after {
    clear: both; }

@media screen and (min-width: 960px) {
  .blog-content-wrapper {
    display: block;
    float: left;
    margin-right: 4.34783%;
    width: 76.81159%; }
    .blog-content-wrapper:last-child {
      margin-right: 0; } }

.blog-meta {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  padding: 15px 0 10px;
  border-bottom: 1px solid #dddddd;
  margin: 0 0 10px; }
  .blog-meta:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-meta {
      display: block;
      float: left;
      margin-right: 4.34783%;
      width: 18.84058%;
      padding: 0 0 10px;
      border-bottom: 0; }
      .blog-meta:last-child {
        margin-right: 0; } }

.blog-date {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  line-height: 45px;
  font-size: 14px;
  text-transform: uppercase;
  letter-spacing: 0.1em;
  margin-bottom: 0; }
  .blog-date:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-date {
      display: block;
      float: left;
      margin-right: 23.07692%;
      width: 100%;
      line-height: 40px;
      text-align: center;
      font-size: 16px; }
      .blog-date:last-child {
        margin-right: 0; } }

.blog-author-imagewrapper {
  text-align: center; }
  .blog-author-imagewrapper img {
    height: 68px;
    width: 68px;
    background: lightgray;
    border-radius: 34px;
    border: 4px solid white;
    box-shadow: 1px 1px 2px rgba(0, 0, 0, 0.3);
    margin: 0 auto 10px; }

.blog-readmore {
  text-transform: uppercase;
  font-weight: 700;
  margin: 0 0 10px; }
  @media screen and (min-width: 960px) {
    .blog-readmore {
      font-size: 14px; } }

.blog-part-footer {
  *zoom: 1;
  display: block;
  padding: 10px 0;
  border-bottom: 1px solid #dddddd; }
  .blog-part-footer:before, .blog-part-footer:after {
    content: " ";
    display: table; }
  .blog-part-footer:after {
    clear: both; }

.blog-author-image {
  height: 68px;
  width: 68px;
  background: lightgray;
  border-radius: 34px;
  border: 4px solid white;
  box-shadow: 1px 1px 2px rgba(0, 0, 0, 0.3);
  margin: 0 auto 10px; }

.blog-author-title {
  letter-spacing: 0.05em;
  text-align: center; }

.blog-author {
  *zoom: 1;
  display: block;
  padding: 0 0 5px;
  border-bottom: 1px solid #b0b0b0;
  margin: 0 0 5px;
  display: none; }
  .blog-author:before, .blog-author:after {
    content: " ";
    display: table; }
  .blog-author:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-author {
      display: block;
      float: left;
      margin-right: 23.07692%;
      width: 100%;
      border-bottom: 0; }
      .blog-author:last-child {
        margin-right: 0; } }

.blog-author-name {
  color: #00ac4d;
  text-transform: uppercase;
  font-size: 14px;
  letter-spacing: 0.1em;
  text-align: center;
  line-height: 20px;
  margin: 0; }

.blog-author-title {
  margin: 0; }

.blog-part-categories, .blog-single-categories {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  margin-bottom: 5px;
  margin-top: 5px;
  padding: 0;
  text-align: right; }
  .blog-part-categories:last-child, .blog-single-categories:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-part-categories, .blog-single-categories {
      display: block;
      float: left;
      margin-right: 4.91803%;
      width: 73.77049%; }
      .blog-part-categories:last-child, .blog-single-categories:last-child {
        margin-right: 0; } }

.cat-item {
  text-transform: capitalize;
  list-style: none; }

.blog-single-categories {
  text-align: left; }
  @media screen and (min-width: 960px) {
    .blog-single-categories {
      display: block;
      float: left;
      margin-right: 6.66667%;
      width: 100%; }
      .blog-single-categories:last-child {
        margin-right: 0; } }

.blog-readmorewrap {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 44.82759%;
  margin-bottom: 5px;
  margin-top: 5px; }
  .blog-readmorewrap:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-readmorewrap {
      display: block;
      float: left;
      margin-right: 4.91803%;
      width: 21.31148%; }
      .blog-readmorewrap:last-child {
        margin-right: 0; } }

.blog-part-category {
  display: inline-block;
  list-style: none;
  font-size: 12px;
  text-transform: uppercase;
  letter-spacing: 0.1em;
  margin: 0 15px 0 0; }
  @media screen and (min-width: 960px) {
    .blog-part-category {
      font-size: 14px; } }

.blog-categorieslist {
  padding: 0;
  margin: 0 0 50px; }

.blog-category {
  list-style: none; }

.blog-comments {
  background: #efecec;
  border-top: 1px solid #d8d0d0;
  padding: 10px; }

.blog-comments-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em; }
  .blog-comments-wrapper:before, .blog-comments-wrapper:after {
    content: " ";
    display: table; }
  .blog-comments-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .blog-comments-wrapper {
      max-width: 60em; } }

.blog-comments-content {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  padding: 10px 0 0 0; }
  .blog-comments-content:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .blog-comments-content {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 56.98925%;
      margin-left: 17.2043%; }
      .blog-comments-content:last-child {
        margin-right: 0; } }

.blog-categoriestitle, .blog-tweetstitle, .blog-socialtitle {
  text-transform: uppercase;
  font-size: 16px;
  letter-spacing: 0.12em;
  margin-bottom: 5px; }

.blog-tweet {
  font-size: 13px;
  padding: 0 0 15px;
  margin: 0 0 15px;
  border-bottom: 1px solid #dddddd; }
  .blog-tweet:last-child {
    border-bottom: 0; }
  .blog-tweet .icon-twitter {
    color: #00acee;
    position: relative;
    top: 6px;
    font-size: 22px; }

.blog-tweet-meta {
  *zoom: 1; }
  .blog-tweet-meta:before, .blog-tweet-meta:after {
    content: " ";
    display: table; }
  .blog-tweet-meta:after {
    clear: both; }

.blog-tweet-who {
  font-size: 13px;
  float: left;
  margin: 0 0 5px; }

.blog-tweet-author {
  padding: 0 5px 0 0; }

.blog-tweet-time {
  padding: 0 0 0 5px; }

.blog-tweet-content {
  font-size: 13px;
  margin: 0 0 5px 0; }

.blog-tweet-when {
  color: #747474;
  font-size: 13px;
  margin: 0;
  float: right; }

.blog-sociallist {
  margin: 0;
  padding: 0; }

.blog-social-item {
  list-style: none;
  display: inline-block;
  margin: 0 1px 1px 0;
  font-size: 28px; }

.blog-part-category a:before, .blog-category a:before {
  position: relative;
  margin-right: 5px;
  top: 6px;
  font-size: 24px;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
.blog-part-category a:hover:before, .blog-category a:hover:before {
  opacity: .7; }

.category-icon-launch:before {
  color: #00b4ea; }

.category-icon-oped:before {
  color: #058eb0; }

.category-icon-news:before {
  color: #00ac4d; }

.blog-social-twitter a:before {
  color: #00acee;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
.blog-social-twitter a:hover:before {
  color: #22c2ff; }

.blog-social-linkedin a:before {
  color: #0e76a8;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
.blog-social-linkedin a:hover:before {
  color: #1297d7; }

.blog-social-googleplus a:before {
  color: #de473d;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
.blog-social-googleplus a:hover:before {
  color: #e57069; }

.blog-social-facebook a:before {
  color: #3b5998;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transition: all 0.3s ease; }
.blog-social-facebook a:hover:before {
  color: #4c70ba; }

.comment-form {
  *zoom: 1;
  margin: 0 0 30px; }
  .comment-form:before, .comment-form:after {
    content: " ";
    display: table; }
  .comment-form:after {
    clear: both; }
  .comment-form #submit {
    border: 0;
    line-height: 35px;
    float: right;
    padding: 0 20px; }

.comment-form-comment label {
  display: block;
  font-size: 21px;
  margin: 0 0 10px; }
.comment-form-comment textarea {
  width: 100%;
  padding: 10px; }

.comment-form-url, .comment-form-email, .comment-form-author {
  margin: 0 0 5px; }
  .comment-form-url label, .comment-form-email label, .comment-form-author label {
    display: block;
    margin: 0 0 5px; }
  .comment-form-url input, .comment-form-email input, .comment-form-author input {
    line-height: 30px;
    padding: 0 5px; }
  .comment-form-url .required, .comment-form-email .required, .comment-form-author .required {
    display: none; }

.comment-author {
  font-style: normal;
  font-weight: 700; }

.comment {
  margin: 0 0 30px;
  *zoom: 1; }
  .comment:before, .comment:after {
    content: " ";
    display: table; }
  .comment:after {
    clear: both; }
  .comment .avatar {
    float: left;
    margin: 0 10px 0 0;
    border: 4px solid white; }

.comment-content {
  margin: 0 0 0 74px; }

.comment-edit-link {
  font-size: 12px;
  margin: 0 0 0 2px; }

.wp-caption {
  margin: 0 0 15px;
  max-width: 100%; }
  .wp-caption img {
    margin: 0 0 15px;
    max-width: 100%;
    height: auto; }
  .wp-caption .wp-caption-text {
    margin: 10px 0; }

.videowrapper {
  position: relative;
  padding-bottom: 56.25%;
  /* 16:9 */
  height: 0; }
  .videowrapper iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100% !important; }

.videowrapper4x3 {
  position: relative;
  padding-bottom: 56.25%;
  /* 16:9 */
  padding-top: 25px;
  height: 0; }
  .videowrapper4x3 iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%; }

.bannerheader {
  background: #f5f6f6;
  background-position: center bottom;
  background-repeat: no-repeat; }

.bannerheader--blue {
  background-color: #00b4ea;
  color: white; }
  .bannerheader--blue .bannerheader-wrapper {
    padding: 80px 10px 30px 10px; }
    @media screen and (min-width: 960px) {
      .bannerheader--blue .bannerheader-wrapper {
        padding: 180px 10px 80px; } }
  .bannerheader--blue .bannerheader-heading:after {
    content: '';
    display: block;
    max-width: 75%;
    margin: 0 auto;
    border-bottom: 1px solid white;
    padding: 5px; }

.bannerheader--cover {
  background-size: cover; }

@media screen and (min-width: 960px) {
  .bannerheader--small .bannerheader-wrapper {
    padding: 150px 10px 40px; } }

.bannerheader-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 80px 10px; }
  .bannerheader-wrapper:before, .bannerheader-wrapper:after {
    content: " ";
    display: table; }
  .bannerheader-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .bannerheader-wrapper {
      max-width: 60em; } }
  @media screen and (min-width: 960px) {
    .bannerheader-wrapper {
      padding: 130px 10px 60px; } }

.bannerheader-heading {
  text-align: center;
  text-transform: uppercase;
  font-size: 20px;
  letter-spacing: 0.05em;
  font-weight: 400;
  line-height: 30px; }
  .bannerheader-heading:after {
    content: '';
    display: block;
    border-bottom: 1px solid #747474;
    max-width: 66%;
    margin: 0 auto;
    padding: 5px; }
  @media screen and (min-width: 960px) {
    .bannerheader-heading {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 82.7957%;
      margin-left: 8.60215%;
      padding: 0 0 5px;
      max-width: none;
      line-height: 45px;
      font-size: 36px; }
      .bannerheader-heading:last-child {
        margin-right: 0; } }

.bannerheader-description {
  text-align: center;
  font-size: 16px;
  line-height: 25px;
  font-weight: 300;
  margin-bottom: 10px;
  letter-spacing: 0.05em;
  padding: 0 20px; }
  @media screen and (min-width: 960px) {
    .bannerheader-description {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 65.5914%;
      margin-left: 17.2043%;
      padding: 0;
      max-width: none;
      font-size: 22px;
      line-height: 25px;
      margin-bottom: 20px; }
      .bannerheader-description:last-child {
        margin-right: 0; } }

.bannerheader-link-wrapper {
  text-align: center;
  margin-top: 6px;
  margin-bottom: 11px; }
  @media screen and (min-width: 960px) {
    .bannerheader-link-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 82.7957%;
      margin-left: 8.60215%; }
      .bannerheader-link-wrapper:last-child {
        margin-right: 0; } }
  .bannerheader-link-wrapper a {
    margin: 6px 0 11px 0;
    color: white;
    border-radius: 20px;
    background: #CB8E00;
    text-transform: uppercase;
    font-size: 13px;
    letter-spacing: .18em;
    font-weight: 700; }
    .bannerheader-link-wrapper a:hover {
      background: #FFB300; }

.bannerheader-mobilebreak {
  display: inline; }
  @media screen and (min-width: 960px) {
    .bannerheader-mobilebreak {
      display: block; } }

.bannerheader-link {
  padding: 10px 40px; }

.sectionheader-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 0 10px; }
  .sectionheader-wrapper:before, .sectionheader-wrapper:after {
    content: " ";
    display: table; }
  .sectionheader-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .sectionheader-wrapper {
      max-width: 60em; } }

.sectionheader {
  background: #f5f6f6; }

.sectionheader--white {
  background: white; }

.sectionheader--bordertop {
  border-top: 1px solid #dddddd; }

.sectionheader--borderbottom {
  border-bottom: 1px solid #dddddd; }

.sectionheader-heading {
  padding: 15px 0;
  text-align: center;
  text-transform: uppercase;
  font-weight: 300;
  margin-bottom: 0;
  font-size: 16px;
  line-height: 30px; }
  @media screen and (min-width: 960px) {
    .sectionheader-heading {
      font-size: 25px;
      line-height: 35px; } }

.calltoaction-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 15px 10px;
  text-align: center; }
  .calltoaction-wrapper:before, .calltoaction-wrapper:after {
    content: " ";
    display: table; }
  .calltoaction-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .calltoaction-wrapper {
      max-width: 60em; } }

.calltoaction {
  background: #f5f6f6; }

.calltoaction--white {
  background: white; }

.calltoaction--bordertop {
  border-top: 1px solid #dddddd; }

.calltoaction--borderbottom {
  border-bottom: 1px solid #dddddd; }

.calltoaction-link {
  margin: 0; }

.panel {
  *zoom: 1;
  display: block;
  background: #f5f6f6; }
  .panel:before, .panel:after {
    content: " ";
    display: table; }
  .panel:after {
    clear: both; }

.panel--bordertop {
  border-top: 1px solid #dddddd; }

.panel--borderbottom {
  border-bottom: 1px solid #dddddd; }

.panel-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 25px 10px 5px;
  margin: 0 auto; }
  .panel-wrapper:before, .panel-wrapper:after {
    content: " ";
    display: table; }
  .panel-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .panel-wrapper {
      max-width: 60em; } }

.panel-item {
  padding: 20px 15px 10px;
  margin: 0 auto 20px;
  background: white;
  max-width: 350px;
  list-style: none; }
  .panel-item:nth-of-type(2n) .panel-heading, .panel-item:nth-of-type(2n) .panel-iconwrapper {
    color: #00ac4d; }
    .panel-item:nth-of-type(2n) .panel-heading:after, .panel-item:nth-of-type(2n) .panel-iconwrapper:after {
      border-color: #00ac4d; }
  .panel-item:nth-of-type(2n) .panel-link {
    line-height: 35px;
    min-width: 66%; }
  .panel-item:nth-of-type(3n) .panel-heading, .panel-item:nth-of-type(3n) .panel-iconwrapper {
    color: #037bac; }
    .panel-item:nth-of-type(3n) .panel-heading:after, .panel-item:nth-of-type(3n) .panel-iconwrapper:after {
      border-color: #037bac; }
  .panel-item:nth-of-type(3n) .panel-link {
    line-height: 35px;
    min-width: 66%; }
  .panel-item:nth-of-type(4n) .panel-heading, .panel-item:nth-of-type(4n) .panel-iconwrapper {
    color: #00b4ea; }
    .panel-item:nth-of-type(4n) .panel-heading:after, .panel-item:nth-of-type(4n) .panel-iconwrapper:after {
      border-color: #00b4ea; }
  .panel-item:nth-of-type(4n) .panel-link {
    line-height: 35px;
    min-width: 66%; }
  @media screen and (min-width: 960px) {
    .panel-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 31.1828%;
      max-width: none; }
      .panel-item:last-child {
        margin-right: 0; }
      .panel-item:nth-child(3n) {
        margin-right: 0; }
      .panel-item:nth-child(3n+1) {
        clear: left; } }

.panel-heading {
  text-align: center;
  text-transform: uppercase;
  color: #00b4ea;
  margin: 0 0 10px;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  .panel-heading:after {
    content: '';
    display: block;
    width: 66%;
    margin: 5px auto 0;
    border-bottom: 1px solid #00b4ea; }

.panel-subheading {
  display: block; }

.panel-content {
  text-align: center;
  font-weight: 300;
  font-size: 15px;
  margin-bottom: 15px; }

.panel-link-wrapper {
  text-align: center; }

.panel-link {
  min-width: 66%; }

.panel-iconwrapper {
  text-align: center;
  font-size: 54px;
  margin: 0 0 10px;
  color: #00b4ea; }

.panel-image {
  max-width: 100%;
  max-height: 54px; }

.large-panel {
  *zoom: 1;
  display: block; }
  .large-panel:before, .large-panel:after {
    content: " ";
    display: table; }
  .large-panel:after {
    clear: both; }

.large-panel-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 25px 10px 5px;
  margin: 0 auto; }
  .large-panel-wrapper:before, .large-panel-wrapper:after {
    content: " ";
    display: table; }
  .large-panel-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .large-panel-wrapper {
      max-width: 60em; } }

.large-panel-item {
  padding: 20px 15px 10px;
  margin: 0 auto 20px;
  max-width: 350px;
  list-style: none; }
  @media screen and (min-width: 960px) {
    .large-panel-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%;
      max-width: none; }
      .large-panel-item:last-child {
        margin-right: 0; }
      .large-panel-item:nth-child(2n) {
        margin-right: 0; }
      .large-panel-item:nth-child(2n+1) {
        clear: left; } }

.large-panel-heading {
  text-align: center;
  text-transform: uppercase;
  color: #037bac;
  margin: 0 0 10px;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  .large-panel-heading:after {
    content: '';
    display: block;
    width: 66%;
    margin: 5px auto 0;
    border-bottom: 1px solid #037bac; }

.large-panel-subheading {
  display: block; }

.large-panel-content {
  text-align: center;
  font-weight: 300;
  font-size: 15px;
  margin-bottom: 15px; }

.large-panel-link-wrapper {
  text-align: center; }

.large-panel-link {
  min-width: 66%; }

.large-panel-iconwrapper {
  text-align: center;
  font-size: 54px;
  margin: 0 0 15px;
  color: #00b4ea; }

.large-panel-image {
  max-width: 100%;
  max-height: 74px; }

.stack {
  background-color: #f5f6f6;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd; }

.stack-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 25px 10px 5px;
  margin: 0 auto;
  text-align: center; }
  .stack-wrapper:before, .stack-wrapper:after {
    content: " ";
    display: table; }
  .stack-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .stack-wrapper {
      max-width: 60em; } }

.stack-list-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%; }
  .stack-list-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .stack-list-wrapper {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 31.1828%; }
      .stack-list-wrapper:last-child {
        margin-right: 0; } }

.stack-title {
  color: #037bac;
  text-transform: uppercase;
  margin: 0 0 5px;
  font-size: 17px;
  line-height: 25px;
  font-weight: 400; }
  @media screen and (min-width: 960px) {
    .stack-title {
      font-size: 20px; } }

.stack-description p {
  margin: 0; }

.stack-list {
  padding: 0;
  *zoom: 1; }
  .stack-list:before, .stack-list:after {
    content: " ";
    display: table; }
  .stack-list:after {
    clear: both; }

.stack-link {
  *zoom: 1;
  -webkit-transition: opacity 0.3s ease;
  -moz-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease; }
  .stack-link:before, .stack-link:after {
    content: " ";
    display: table; }
  .stack-link:after {
    clear: both; }
  .stack-link:hover img, .stack-link:active img {
    opacity: .6; }

.stack-item {
  list-style: none;
  border-top: 1px solid #f5f6f6;
  border-bottom: 1px solid #f5f6f6;
  margin: 0;
  padding: 10px 5px;
  text-align: center;
  width: 33%;
  float: left; }

.stack-image {
  max-width: 100%;
  display: block;
  margin: 0 auto; }

.quote-wrapper {
  border: 1px solid #dddddd;
  margin: 20px 0; }

.quote {
  padding: 0 10px;
  max-width: 50em; }

.quote-content {
  padding: 20px 30px; }

.quote-attribution {
  margin-bottom: 0;
  background: #f5f6f6;
  border-top: 1px solid #dddddd;
  font-weight: 400;
  margin-bottom: 0;
  position: relative;
  padding: 10px 30px; }
  .quote-attribution p {
    margin-bottom: 0; }
    .quote-attribution p:before {
      content: "—";
      position: absolute;
      left: 15px; }

.quote-content, .quote-content p {
  font-size: 16px;
  margin-bottom: 0; }
  @media screen and (min-width: 960px) {
    .quote-content, .quote-content p {
      font-size: 18px; } }

.quote--blue .quote-wrapper {
  border: 1px solid rgba(3, 123, 172, 0.3); }
.quote--blue .quote-attribution {
  color: white;
  background: #037bac;
  border-top: 1px solid rgba(3, 123, 172, 0.3); }

.partners {
  background-color: #f5f6f6;
  border-top: 1px solid #dddddd;
  border-bottom: 1px solid #dddddd;
  min-height: 135px; }

.partner-list {
  padding: 0;
  font-size: 0;
  min-height: 135px;
  position: relative;
  *zoom: 1; }
  .partner-list:before, .partner-list:after {
    content: " ";
    display: table; }
  .partner-list:after {
    clear: both; }

.partner-list.fail:after {
  content: "No results found!";
  display: block;
  position: absolute;
  width: 100%;
  top: 25px;
  left: 0;
  text-align: center;
  font-size: 25px; }

.partner-link {
  *zoom: 1; }
  .partner-link:before, .partner-link:after {
    content: " ";
    display: table; }
  .partner-link:after {
    clear: both; }
  .partner-link:hover img, .partner-link:active img {
    opacity: .6; }

.partner {
  list-style: none;
  border-top: 1px solid #f5f6f6;
  border-bottom: 1px solid #f5f6f6;
  margin: 0;
  padding: 10px 5px;
  text-align: center;
  width: 33%;
  display: inline-block; }
  @media screen and (min-width: 960px) {
    .partner {
      width: 12.5%; } }

.partner-image {
  max-width: 100%;
  display: block;
  margin: 0 auto;
  -webkit-transition: opacity 0.3s ease;
  -moz-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease; }

.mwfilter {
  padding: 20px 0; }

.filter-title {
  margin-right: 10px; }

#grid .mix {
  opacity: 0;
  display: none; }

.date-wrapper {
  *zoom: 1;
  max-width: 60em;
  margin-left: auto;
  margin-right: auto;
  max-width: 32.5em;
  padding: 30px 10px; }
  .date-wrapper:before, .date-wrapper:after {
    content: " ";
    display: table; }
  .date-wrapper:after {
    clear: both; }
  @media screen and (min-width: 960px) {
    .date-wrapper {
      max-width: 60em; } }

.date-item {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 100%;
  margin-bottom: 10px; }
  .date-item:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .date-item {
      display: block;
      float: left;
      margin-right: 3.22581%;
      width: 48.3871%; }
      .date-item:last-child {
        margin-right: 0; }
      .date-item:nth-child(2n) {
        margin-right: 0;
        margin-bottom: 40px; } }

.date-circle-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 17.24138%; }
  .date-circle-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .date-circle-wrapper {
      display: block;
      float: left;
      margin-right: 6.66667%;
      width: 28.88889%; }
      .date-circle-wrapper:last-child {
        margin-right: 0; } }

.date-content-wrapper {
  display: block;
  float: left;
  margin-right: 10.34483%;
  width: 72.41379%; }
  .date-content-wrapper:last-child {
    margin-right: 0; }
  @media screen and (min-width: 960px) {
    .date-content-wrapper {
      display: block;
      float: left;
      margin-right: 6.66667%;
      width: 64.44444%; }
      .date-content-wrapper:last-child {
        margin-right: 0; } }

.date-circle {
  background: #dddddd;
  width: 80px;
  height: 80px;
  border-radius: 40px;
  margin: 0 auto;
  display: block;
  text-align: center;
  padding-top: 8px;
  color: #4c4c4c;
  -webkit-transition: opacity 0.3s ease;
  -moz-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease; }
  .date-circle:link, .date-circle:visited {
    color: #4c4c4c; }
  .date-circle:hover {
    opacity: .66; }

.date-month, .date-day, .date-year {
  display: block; }

.date-month {
  font-size: 20px;
  line-height: 20px; }

.date-day {
  font-size: 24px;
  line-height: 25px; }

.date-year {
  line-height: 20px;
  font-size: 14px; }

.date-content p {
  font-size: 14px; }

.date-title {
  font-size: 16px;
  line-height: 20px;
  font-weight: 300;
  margin-bottom: 0; }

.date-link {
  display: block; }

