@for $i from 1 through 2 {
  %shift-#{$i - 1} {
    margin-left: $i * 1px;
  }
  .week-start-#{$i} {
    @for $j from 1 through 2 {
      .month-start-#{$j} {
        @extend %shift-#{($j - $i - 1) % 2};
      }
    }
  }
}
