.parent {
    .brother, .sister, .cousin {
        color: green;
        sel: &;

        $new-sel: ();
        @each $s in & {
            $last: nth($s, -1);
            $new-sel: append($new-sel, $s #{'+'} $last, comma);
            x: $new-sel;
        }
        @at-root #{$new-sel} {
            debug: foo;
        }
    }
}