.bracketed-lists {
  empty: [];
  single: [foo];
  multiple: [foo, bar];
  nested: [[foo], [[bar, baz]]];
  space-separated: [foo bar baz];
  trailing-comma: [foo, bar];
  nth-comma: bar;
  nth-space: bar;
  comma-separator: comma;
  space-separator: space;
  set-nth: [foo, qux, baz];
  append: [foo, bar, baz];
  append-with-separator: [foo bar baz];
  inspect-empty: [];
  inspect-simple: [foo, bar];
  inspect-nested-bracketed: [[foo]];
  inspect-nested-unbracketed: [(foo bar)];
  inspect-nested-unbracketed-comma: [foo bar,];
  inspect-nested-unbracketed-singleton: [(foo,)]; }
