.result { dquoted: "gamme ' delta '"; dquoted: "[gamme ' delta ']"; dquoted: "gamme ' delta '"; dquoted: "gamme ' delta '"; dquoted: "['gamme ' delta '']"; squoted: "gamme ' delta '"; squoted: "[gamme ' delta ']"; squoted: "gamme ' delta '"; squoted: "gamme ' delta '"; squoted: "['gamme ' delta '']"; }
