foo {
  c-361: black;
  c-360: black;
  c-359: black;
  c-358: black;
  c-357: black;
  c-356: black;
  c-355: black;
  c-354: black;
  c-353: black;
  c-352: black;
  c-351: black;
  c-350: black;
  c-349: black;
  c-348: black;
  c-347: black;
  c-346: black;
  c-345: black;
  c-344: black;
  c-343: black;
  c-342: black;
  c-341: black;
  c-340: black;
  c-339: black;
  c-338: black;
  c-337: black;
  c-336: black;
  c-335: black;
  c-334: black;
  c-333: black;
  c-332: black;
  c-331: black;
  c-330: black;
  c-329: black;
  c-328: black;
  c-327: black;
  c-326: black;
  c-325: black;
  c-324: black;
  c-323: black;
  c-322: black;
  c-321: black;
  c-320: black;
  c-319: black;
  c-318: black;
  c-317: black;
  c-316: black;
  c-315: black;
  c-314: black;
  c-313: black;
  c-312: black;
  c-311: black;
  c-310: black;
  c-309: black;
  c-308: black;
  c-307: black;
  c-306: black;
  c-305: black;
  c-304: black;
  c-303: black;
  c-302: black;
  c-301: black;
  c-300: black;
  c-299: black;
  c-298: black;
  c-297: black;
  c-296: black;
  c-295: black;
  c-294: black;
  c-293: black;
  c-292: black;
  c-291: black;
  c-290: black;
  c-289: black;
  c-288: black;
  c-287: black;
  c-286: black;
  c-285: black;
  c-284: black;
  c-283: black;
  c-282: black;
  c-281: black;
  c-280: black;
  c-279: black;
  c-278: black;
  c-277: black;
  c-276: black;
  c-275: black;
  c-274: black;
  c-273: black;
  c-272: black;
  c-271: black;
  c-270: black;
  c-269: black;
  c-268: black;
  c-267: black;
  c-266: black;
  c-265: black;
  c-264: black;
  c-263: black;
  c-262: black;
  c-261: black;
  c-260: black;
  c-259: black;
  c-258: black;
  c-257: black;
  c-256: black;
  c-255: black;
  c-254: black;
  c-253: black;
  c-252: black;
  c-251: black;
  c-250: black;
  c-249: black;
  c-248: black;
  c-247: black;
  c-246: black;
  c-245: black;
  c-244: black;
  c-243: black;
  c-242: black;
  c-241: black;
  c-240: black;
  c-239: black;
  c-238: black;
  c-237: black;
  c-236: black;
  c-235: black;
  c-234: black;
  c-233: black;
  c-232: black;
  c-231: black;
  c-230: black;
  c-229: black;
  c-228: black;
  c-227: black;
  c-226: black;
  c-225: black;
  c-224: black;
  c-223: black;
  c-222: black;
  c-221: black;
  c-220: black;
  c-219: black;
  c-218: black;
  c-217: black;
  c-216: black;
  c-215: black;
  c-214: black;
  c-213: black;
  c-212: black;
  c-211: black;
  c-210: black;
  c-209: black;
  c-208: black;
  c-207: black;
  c-206: black;
  c-205: black;
  c-204: black;
  c-203: black;
  c-202: black;
  c-201: black;
  c-200: black;
  c-199: black;
  c-198: black;
  c-197: black;
  c-196: black;
  c-195: black;
  c-194: black;
  c-193: black;
  c-192: black;
  c-191: black;
  c-190: black;
  c-189: black;
  c-188: black;
  c-187: black;
  c-186: black;
  c-185: black;
  c-184: black;
  c-183: black;
  c-182: black;
  c-181: black;
  c-180: black;
  c-179: black;
  c-178: black;
  c-177: black;
  c-176: black;
  c-175: black;
  c-174: black;
  c-173: black;
  c-172: black;
  c-171: black;
  c-170: black;
  c-169: black;
  c-168: black;
  c-167: black;
  c-166: black;
  c-165: black;
  c-164: black;
  c-163: black;
  c-162: black;
  c-161: black;
  c-160: black;
  c-159: black;
  c-158: black;
  c-157: black;
  c-156: black;
  c-155: black;
  c-154: black;
  c-153: black;
  c-152: black;
  c-151: black;
  c-150: black;
  c-149: black;
  c-148: black;
  c-147: black;
  c-146: black;
  c-145: black;
  c-144: black;
  c-143: black;
  c-142: black;
  c-141: black;
  c-140: black;
  c-139: black;
  c-138: black;
  c-137: black;
  c-136: black;
  c-135: black;
  c-134: black;
  c-133: black;
  c-132: black;
  c-131: black;
  c-130: black;
  c-129: black;
  c-128: black;
  c-127: black;
  c-126: black;
  c-125: black;
  c-124: black;
  c-123: black;
  c-122: black;
  c-121: black;
  c-120: black;
  c-119: black;
  c-118: black;
  c-117: black;
  c-116: black;
  c-115: black;
  c-114: black;
  c-113: black;
  c-112: black;
  c-111: black;
  c-110: black;
  c-109: black;
  c-108: black;
  c-107: black;
  c-106: black;
  c-105: black;
  c-104: black;
  c-103: black;
  c-102: black;
  c-101: black;
  c-100: black;
  c-99: black;
  c-98: black;
  c-97: black;
  c-96: black;
  c-95: black;
  c-94: black;
  c-93: black;
  c-92: black;
  c-91: black;
  c-90: black;
  c-89: black;
  c-88: black;
  c-87: black;
  c-86: black;
  c-85: black;
  c-84: black;
  c-83: black;
  c-82: black;
  c-81: black;
  c-80: black;
  c-79: black;
  c-78: black;
  c-77: black;
  c-76: black;
  c-75: black;
  c-74: black;
  c-73: black;
  c-72: black;
  c-71: black;
  c-70: black;
  c-69: black;
  c-68: black;
  c-67: black;
  c-66: black;
  c-65: black;
  c-64: black;
  c-63: black;
  c-62: black;
  c-61: black;
  c-60: black;
  c-59: black;
  c-58: black;
  c-57: black;
  c-56: black;
  c-55: black;
  c-54: black;
  c-53: black;
  c-52: black;
  c-51: black;
  c-50: black;
  c-49: black;
  c-48: black;
  c-47: black;
  c-46: black;
  c-45: black;
  c-44: black;
  c-43: black;
  c-42: black;
  c-41: black;
  c-40: black;
  c-39: black;
  c-38: black;
  c-37: black;
  c-36: black;
  c-35: black;
  c-34: black;
  c-33: black;
  c-32: black;
  c-31: black;
  c-30: black;
  c-29: black;
  c-28: black;
  c-27: black;
  c-26: black;
  c-25: black;
  c-24: black;
  c-23: black;
  c-22: black;
  c-21: black;
  c-20: black;
  c-19: black;
  c-18: black;
  c-17: black;
  c-16: black;
  c-15: black;
  c-14: black;
  c-13: black;
  c-12: black;
  c-11: black;
  c-10: black;
  c-9: black;
  c-8: black;
  c-7: black;
  c-6: black;
  c-5: black;
  c-4: black;
  c-3: black;
  c-2: black;
  c-1: black;
  c0: black;
  c1: black;
  c2: black;
  c3: black;
  c4: black;
  c5: black;
  c6: black;
  c7: black;
  c8: black;
  c9: black;
  c10: black;
  c11: black;
  c12: black;
  c13: black;
  c14: black;
  c15: black;
  c16: black;
  c17: black;
  c18: black;
  c19: black;
  c20: black;
  c21: black;
  c22: black;
  c23: black;
  c24: black;
  c25: black;
  c26: black;
  c27: black;
  c28: black;
  c29: black;
  c30: black;
  c31: black;
  c32: black;
  c33: black;
  c34: black;
  c35: black;
  c36: black;
  c37: black;
  c38: black;
  c39: black;
  c40: black;
  c41: black;
  c42: black;
  c43: black;
  c44: black;
  c45: black;
  c46: black;
  c47: black;
  c48: black;
  c49: black;
  c50: black;
  c51: black;
  c52: black;
  c53: black;
  c54: black;
  c55: black;
  c56: black;
  c57: black;
  c58: black;
  c59: black;
  c60: black;
  c61: black;
  c62: black;
  c63: black;
  c64: black;
  c65: black;
  c66: black;
  c67: black;
  c68: black;
  c69: black;
  c70: black;
  c71: black;
  c72: black;
  c73: black;
  c74: black;
  c75: black;
  c76: black;
  c77: black;
  c78: black;
  c79: black;
  c80: black;
  c81: black;
  c82: black;
  c83: black;
  c84: black;
  c85: black;
  c86: black;
  c87: black;
  c88: black;
  c89: black;
  c90: black;
  c91: black;
  c92: black;
  c93: black;
  c94: black;
  c95: black;
  c96: black;
  c97: black;
  c98: black;
  c99: black;
  c100: black;
  c101: black;
  c102: black;
  c103: black;
  c104: black;
  c105: black;
  c106: black;
  c107: black;
  c108: black;
  c109: black;
  c110: black;
  c111: black;
  c112: black;
  c113: black;
  c114: black;
  c115: black;
  c116: black;
  c117: black;
  c118: black;
  c119: black;
  c120: black;
  c121: black;
  c122: black;
  c123: black;
  c124: black;
  c125: black;
  c126: black;
  c127: black;
  c128: black;
  c129: black;
  c130: black;
  c131: black;
  c132: black;
  c133: black;
  c134: black;
  c135: black;
  c136: black;
  c137: black;
  c138: black;
  c139: black;
  c140: black;
  c141: black;
  c142: black;
  c143: black;
  c144: black;
  c145: black;
  c146: black;
  c147: black;
  c148: black;
  c149: black;
  c150: black;
  c151: black;
  c152: black;
  c153: black;
  c154: black;
  c155: black;
  c156: black;
  c157: black;
  c158: black;
  c159: black;
  c160: black;
  c161: black;
  c162: black;
  c163: black;
  c164: black;
  c165: black;
  c166: black;
  c167: black;
  c168: black;
  c169: black;
  c170: black;
  c171: black;
  c172: black;
  c173: black;
  c174: black;
  c175: black;
  c176: black;
  c177: black;
  c178: black;
  c179: black;
  c180: black;
  c181: black;
  c182: black;
  c183: black;
  c184: black;
  c185: black;
  c186: black;
  c187: black;
  c188: black;
  c189: black;
  c190: black;
  c191: black;
  c192: black;
  c193: black;
  c194: black;
  c195: black;
  c196: black;
  c197: black;
  c198: black;
  c199: black;
  c200: black;
  c201: black;
  c202: black;
  c203: black;
  c204: black;
  c205: black;
  c206: black;
  c207: black;
  c208: black;
  c209: black;
  c210: black;
  c211: black;
  c212: black;
  c213: black;
  c214: black;
  c215: black;
  c216: black;
  c217: black;
  c218: black;
  c219: black;
  c220: black;
  c221: black;
  c222: black;
  c223: black;
  c224: black;
  c225: black;
  c226: black;
  c227: black;
  c228: black;
  c229: black;
  c230: black;
  c231: black;
  c232: black;
  c233: black;
  c234: black;
  c235: black;
  c236: black;
  c237: black;
  c238: black;
  c239: black;
  c240: black;
  c241: black;
  c242: black;
  c243: black;
  c244: black;
  c245: black;
  c246: black;
  c247: black;
  c248: black;
  c249: black;
  c250: black;
  c251: black;
  c252: black;
  c253: black;
  c254: black;
  c255: black;
  c256: black;
  c257: black;
  c258: black;
  c259: black;
  c260: black;
  c261: black;
  c262: black;
  c263: black;
  c264: black;
  c265: black;
  c266: black;
  c267: black;
  c268: black;
  c269: black;
  c270: black;
  c271: black;
  c272: black;
  c273: black;
  c274: black;
  c275: black;
  c276: black;
  c277: black;
  c278: black;
  c279: black;
  c280: black;
  c281: black;
  c282: black;
  c283: black;
  c284: black;
  c285: black;
  c286: black;
  c287: black;
  c288: black;
  c289: black;
  c290: black;
  c291: black;
  c292: black;
  c293: black;
  c294: black;
  c295: black;
  c296: black;
  c297: black;
  c298: black;
  c299: black;
  c300: black;
  c301: black;
  c302: black;
  c303: black;
  c304: black;
  c305: black;
  c306: black;
  c307: black;
  c308: black;
  c309: black;
  c310: black;
  c311: black;
  c312: black;
  c313: black;
  c314: black;
  c315: black;
  c316: black;
  c317: black;
  c318: black;
  c319: black;
  c320: black;
  c321: black;
  c322: black;
  c323: black;
  c324: black;
  c325: black;
  c326: black;
  c327: black;
  c328: black;
  c329: black;
  c330: black;
  c331: black;
  c332: black;
  c333: black;
  c334: black;
  c335: black;
  c336: black;
  c337: black;
  c338: black;
  c339: black;
  c340: black;
  c341: black;
  c342: black;
  c343: black;
  c344: black;
  c345: black;
  c346: black;
  c347: black;
  c348: black;
  c349: black;
  c350: black;
  c351: black;
  c352: black;
  c353: black;
  c354: black;
  c355: black;
  c356: black;
  c357: black;
  c358: black;
  c359: black;
  c360: black;
  c361: black; }
