.result { output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: literal literal; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; output: "literal  literal"; }
