.simple {
  a: selector-nest('.foo');
  b: selector-nest('.foo', '.bar');
  c: selector-nest('.foo', '.bar', '.baz');
  d: selector-nest('.a .foo', '.b .bar');
  e: selector-nest('.foo', '&.bar');
  e: selector-nest('.foo', '&.bar', '.baz &');
}