.join {
  both-bracketed: [foo bar baz bang];
  first-bracketed: [foo bar baz bang];
  second-bracketed: foo bar baz bang;
  bracketed-true: [foo bar];
  bracketed-false: foo bar;
  separator-and-bracketed: [foo, bar];
  bracketed-and-separator: [foo, bar];
  separator-and-bracketed-positional: [foo, bar];
  unusual-bracketed-type: [foo bar];
  bracketed-null: foo bar; }
