@mixin foo($x, $y) {
  hugabug: $y $x;
}

@mixin bar($a, $b: flug) {
  flugablug: $a $b glug;
}

@mixin hux() {
  no: parameters here;
  div, span {
    some: nested stuff;
    foo, bar {
      more: stuff so forth;
      blah: blah;
    }
  }
  /* end of hux */
}

a {
  hey: ho;
  @include foo(second, third);
  @include foo($y: kwd-y, $x: kwd-x);
  goo: boo hoo;
  @include hux;
  @include bar(pug);
  @include bar(pug, mug);
}


$x: from a variable;

div {
  blah: blah $x blah;
}