@font-face{font-family:'My Font';font-style:normal;font-weight:300;src:local("My Font"),local("My-Font"),url("my-font.eot?#iefix") format("embedded-opentype"),url("my-font.woff") format("woff"),url("my-font.ttf") format("truetype"),url("my-font.svg#MyFont") format("svg")}
