%place-to-go {
  font-size: 1em;
}

a::foo(1){
  @extend %place-to-go;
}
a::foo(2){
  @extend %place-to-go;
}
b::foo(1){
  @extend %place-to-go;
}
b::foo(2){
  @extend %place-to-go;
}

:bar(1){
  @extend %place-to-go;
}
:bar(2){
  @extend %place-to-go;
}
:bar(3){
  @extend %place-to-go;
}

[foo]{
  @extend %place-to-go;
}
[bar]{
  @extend %place-to-go;
}
[baz]{
  @extend %place-to-go;
}

[bar="1"]{
  @extend %place-to-go;
}
[bar="2"]{
  @extend %place-to-go;
}
[bar="3"]{
  @extend %place-to-go;
}
