foo {
  // c-1: mix(black,white,-1%);
  c0: mix(black,white,0%);
  c1: mix(black,white,1%);
  c2: mix(black,white,2%);
  c3: mix(black,white,3%);
  c4: mix(black,white,4%);
  c5: mix(black,white,5%);
  c6: mix(black,white,6%);
  c7: mix(black,white,7%);
  c8: mix(black,white,8%);
  c9: mix(black,white,9%);
  c10: mix(black,white,10%);
  c11: mix(black,white,11%);
  c12: mix(black,white,12%);
  c13: mix(black,white,13%);
  c14: mix(black,white,14%);
  c15: mix(black,white,15%);
  c16: mix(black,white,16%);
  c17: mix(black,white,17%);
  c18: mix(black,white,18%);
  c19: mix(black,white,19%);
  c20: mix(black,white,20%);
  c21: mix(black,white,21%);
  c22: mix(black,white,22%);
  c23: mix(black,white,23%);
  c24: mix(black,white,24%);
  c25: mix(black,white,25%);
  c26: mix(black,white,26%);
  c27: mix(black,white,27%);
  c28: mix(black,white,28%);
  c29: mix(black,white,29%);
  c30: mix(black,white,30%);
  c31: mix(black,white,31%);
  c32: mix(black,white,32%);
  c33: mix(black,white,33%);
  c34: mix(black,white,34%);
  c35: mix(black,white,35%);
  c36: mix(black,white,36%);
  c37: mix(black,white,37%);
  c38: mix(black,white,38%);
  c39: mix(black,white,39%);
  c40: mix(black,white,40%);
  c41: mix(black,white,41%);
  c42: mix(black,white,42%);
  c43: mix(black,white,43%);
  c44: mix(black,white,44%);
  c45: mix(black,white,45%);
  c46: mix(black,white,46%);
  c47: mix(black,white,47%);
  c48: mix(black,white,48%);
  c49: mix(black,white,49%);
  c50: mix(black,white,50%);
  c51: mix(black,white,51%);
  c52: mix(black,white,52%);
  c53: mix(black,white,53%);
  c54: mix(black,white,54%);
  c55: mix(black,white,55%);
  c56: mix(black,white,56%);
  c57: mix(black,white,57%);
  c58: mix(black,white,58%);
  c59: mix(black,white,59%);
  c60: mix(black,white,60%);
  c61: mix(black,white,61%);
  c62: mix(black,white,62%);
  c63: mix(black,white,63%);
  c64: mix(black,white,64%);
  c65: mix(black,white,65%);
  c66: mix(black,white,66%);
  c67: mix(black,white,67%);
  c68: mix(black,white,68%);
  c69: mix(black,white,69%);
  c70: mix(black,white,70%);
  c71: mix(black,white,71%);
  c72: mix(black,white,72%);
  c73: mix(black,white,73%);
  c74: mix(black,white,74%);
  c75: mix(black,white,75%);
  c76: mix(black,white,76%);
  c77: mix(black,white,77%);
  c78: mix(black,white,78%);
  c79: mix(black,white,79%);
  c80: mix(black,white,80%);
  c81: mix(black,white,81%);
  c82: mix(black,white,82%);
  c83: mix(black,white,83%);
  c84: mix(black,white,84%);
  c85: mix(black,white,85%);
  c86: mix(black,white,86%);
  c87: mix(black,white,87%);
  c88: mix(black,white,88%);
  c89: mix(black,white,89%);
  c90: mix(black,white,90%);
  c91: mix(black,white,91%);
  c92: mix(black,white,92%);
  c93: mix(black,white,93%);
  c94: mix(black,white,94%);
  c95: mix(black,white,95%);
  c96: mix(black,white,96%);
  c97: mix(black,white,97%);
  c98: mix(black,white,98%);
  c99: mix(black,white,99%);
  c100: mix(black,white,100%);
  // c101: mix(black,white,101%);
}
