result { continue_outer: true; continue_inner: true; check_implicit: initial; check_explicit: inner; check_default: initial; root_default: initial; root_implicit: initial; root_explicit: inner; local_explicit: inner; }
