foo{test-1:false;test-2:false;test-3:false;test-4:false;test-5:false;test-6:false;test-7:false;test-8:false;test-9:false;test-10:false;test-11:false;test-12:false;test-13:true;test-14:true;test-15:true;test-16:true;test-17:true;test-18:true;test-19:true;test-20:true;test-21:false;test-22:false;test-23:false;test-24:false;test-25:true;test-26:true;test-27:true;test-28:true;test-29:true;test-30:true;test-31:true;test-32:true;test-33:true;test-34:true;test-35:true;test-36:true;test-37:false;test-38:false;test-39:false;test-40:false;test-41:true;test-42:true;test-43:true;test-44:true;test-45:true;test-46:true;test-47:true;test-48:true;test-49:false;test-50:false;test-51:false;test-52:false;test-53:true;test-54:true;test-55:true;test-56:true;test-57:false;test-58:false;test-59:false;test-60:false}
