foo {
  baz: 1;
  baz: list;
  baz: (foo,);
}

bar {
  baz: 1;
  baz: list;
  baz: (bar,);
}

foo {
  string: (foo,);
  str-length: 6;
  list-length: 1;
}

foo, bar {
  string: foo, bar;
  str-length: 8;
  list-length: 2;
}
