.result { dquoted: "literal"; dquoted: "[literal]"; dquoted: "literal"; dquoted: "literal"; dquoted: "['literal']"; squoted: "literal"; squoted: "[literal]"; squoted: "literal"; squoted: "literal"; squoted: "['literal']"; }
