$foo: 42;
$bar: 43;
$baz: 45;

foo {
  foo: $foo;
  bar: $bar;
  baz: $baz;

  $bar: 4; // this is a different $bar than `$bar !global`

  foo: $foo;
  bar: $bar;
  baz: $baz;

  @if true {
    $foo: 3; // this is a different $foo than `$foo !global`
    $bar: 5; // this is a different $bar than `$bar !global`

    foo: $foo;
    bar: $bar;
    baz: $baz;
  }
}
