.result {
  output: "alpha", 'beta';
  output: #{"alpha", 'beta'};
  output: "[#{"alpha", 'beta'}]";
  output: "#{"alpha", 'beta'}";
  output: '#{"alpha", 'beta'}';
  output: "['#{"alpha", 'beta'}']";
}
