.result {
  output: gamme "'"delta"'";
  output: #{gamme "'"delta"'"};
  output: "[#{gamme "'"delta"'"}]";
  output: "#{gamme "'"delta"'"}";
  output: '#{gamme "'"delta"'"}';
  output: "['#{gamme "'"delta"'"}']";
}
