@media screen and (max-width: 300px) {
  a: b;
}
@media screen and (max-width: 300px) {
  a: b;
}
@media screen and (max-width: 300px) {
  a: b;
}
@media screen and (max-width: 300px), print and (max-width: 300px) {
  a: b;
}
