foo {
  test-37: #{interpolant}>#{interpolant};
  test-38: #{interpolant} >#{interpolant};
  test-39: #{interpolant}> #{interpolant};
  test-40: #{interpolant} > #{interpolant};
  test-41: #{interpolant}>lschema_#{ritlp};
  test-42: #{interpolant} >lschema_#{ritlp};
  test-43: #{interpolant}> lschema_#{ritlp};
  test-44: #{interpolant} > lschema_#{ritlp};
  test-45: #{interpolant}>#{litlp}_rschema;
  test-46: #{interpolant} >#{litlp}_rschema;
  test-47: #{interpolant}> #{litlp}_rschema;
  test-48: #{interpolant} > #{litlp}_rschema;
  test-49: lschema_#{ritlp}>lschema_#{ritlp};
  test-50: lschema_#{ritlp} >lschema_#{ritlp};
  test-51: lschema_#{ritlp}> lschema_#{ritlp};
  test-52: lschema_#{ritlp} > lschema_#{ritlp};
  test-53: lschema_#{ritlp}>#{litlp}_rschema;
  test-54: lschema_#{ritlp} >#{litlp}_rschema;
  test-55: lschema_#{ritlp}> #{litlp}_rschema;
  test-56: lschema_#{ritlp} > #{litlp}_rschema;
  test-57: #{litlp}_rschema>#{litlp}_rschema;
  test-58: #{litlp}_rschema >#{litlp}_rschema;
  test-59: #{litlp}_rschema> #{litlp}_rschema;
  test-60: #{litlp}_rschema > #{litlp}_rschema;
}
