
@mixin foo($x, $y) {
  color: $x, $y;
}

div {
  color: type-of(red);
  color: type-of("red");
  color: type-of(#abc);
  color: type-of(123);
  color: type-of(45px);
  color: type-of(98%);
  color: type-of(1 2 3);
  color: type-of(hey);
  color: type-of("ho");
  color: type-of(#{1+2}px);
  color: type-of(true);
  color: type-of(false);
  color: type-of(45 or false);
  color: type-of(#{#abc});
  color: ty#{pe}-of(red);
  color: quote(le#{ng}th(a b c d));
  color: aqua;
  $x : aqua;
  color: $x;
  color: $x + #000000;
  color: $x;
  width: #{1+2}+3;
  thing: url(type-of(3+3));
  //foo + bar: 3px;
}

//@import url(type-of(3+3));
