.test{function:true;function:true;function:true;function:true;function:false;function:false;function:true;mixin:true;mixin:true;mixin:true;mixin:true;mixin:false;mixin:false;mixin:true;variable:true;variable:true;variable:true;variable:true;variable:false;variable:false;variable:true;global-variable:true;global-variable:true;global-variable:true;global-variable:true;global-variable:false;global-variable:false;global-variable:true}
