div.colors { background: gray; background: saturate(red); background: cyan; background: 1; color: #666666; color: saturate(#369); color: #1f66ad; color: #cc9966; color: 1; }

div.numbers { filter: grayscale(30%); filter: saturate(30%); filter: invert(30%); -webkit-filter: grayscale(0.3); -webkit-filter: saturate(0.3); -webkit-filter: invert(0.3); }
