@mixin spec1($decimal) {
  $decimal: unquote($decimal) * -1;
  value: $decimal;
}

@mixin spec2($decimal) {
  $decimal: -1 * unquote($decimal);
  value: $decimal;
}

@mixin spec3($decimal) {
  value: #{$decimal * -1};
}

.my-element {
  @include spec1(3);
  @include spec1(-3);
  @include spec2(5);
  @include spec2(-5);
  @include spec3(7);
  @include spec3(-7);
}