$input: literal;
.result {
  output: literal$input;
  output: literal#{$input};
  output: literal#{literal};
  output: literal#{"literal"};
  output: $input$input;
  output: $input#{$input};
  output: $input#{literal};
  output: $input#{"literal"};
  output: #{$input}literal;
  output: #{$input}$input;
  output: #{$input}#{$input};
  output: #{$input}#{literal};
  output: #{$input}#{"literal"};
  output: #{literal}literal;
  output: #{literal}$input;
  output: #{literal}#{$input};
  output: #{literal}#{literal};
  output: #{literal}#{"literal"};
  output: #{"literal"}literal;
  output: #{"literal"}$input;
  output: #{"literal"}#{$input};
  output: #{"literal"}#{literal};
  output: #{"literal"}#{"literal"};
  output: "literal#{$input}";
  output: "literal#{literal}";
  output: "literal#{"literal"}";
  output: "#{$input}literal";
  output: "#{$input}#{$input}";
  output: "#{$input}#{literal}";
  output: "#{$input}#{"literal"}";
  output: "#{literal}literal";
  output: "#{literal}#{$input}";
  output: "#{literal}#{literal}";
  output: "#{literal}#{"literal"}";
  output: "#{"literal"}literal";
  output: "#{"literal"}#{$input}";
  output: "#{"literal"}#{literal}";
  output: "#{"literal"}#{"literal"}";
}