.foo {
  @media all {
    content: baz;

    @media (min-width: 1337px) {
      content: bar;
    }
  }
}

.foo {
  @media all {
    content: baz;

    @media (min-width: 1337px) {
      content: foo;

      @media (max-width: 42em) {
        content: bar;
      }
    }
  }
}
