.test .nest {
  length: length(&);
  @each $list in & {
    list: $list;
    length: length($list);
  }
}

.test, .other {
  length: length(&);
  @each $list in & {
    list: $list;
    length: length($list);
  }
}
