$viewport1: "only screen";
$viewport2: "(min-width: 700px)";

$foo: "(max-width: ";
$bar: "1920px)";

// Will not work
@media #{$viewport1} and #{$viewport2} and #{$foo+$bar} {
  body {
    background: #3d3d3d;
  }
}