div.colors {
  background: grayscale(red);
  background: saturate(red);
  background: invert(red);
  background: alpha(red);
  color: grayscale(#369);
  color: saturate(#369);
  color: saturate(#369, 20%);
  color: invert(#369);
  color: alpha(#369);
}

div.numbers {
  filter: grayscale(30%);
  filter: saturate(30%);
  filter: invert(30%);
  -webkit-filter: grayscale(0.3);
  -webkit-filter: saturate(0.3);
  -webkit-filter: invert(0.3);
}