:root .foo-1, :root .bar-1 .baz-1 { test: 1; }

.foo-2:root .bar-2, .baz-2.foo-2:root .bang-2 { test: 2; }

html:root .bar-3 { test: 3; }

.foo-4:root > .bar-4 .x-4, .baz-4.foo-4:root > .bar-4 .bang-4 .y-4 { test: 4; }
