div {

  bar: str-slice("ab→cde→dfjgdsja", 2, 7);
  bar: str-slice("abcd", 2);
  bar: str-slice("abcdefg", -3, -2);
  bar: str-slice("abcd", 2, -2);
  bar: str-slice("abcd", 3, 2);
  bar: str-slice("abcd", 29, 180);
  bar: str-slice("abcd", 1, 29);
  bar: str-slice("abcd", 0, 5);

  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 2, 3);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 2, 9);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 2);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", -3, -2);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 2, -2);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 3, 2);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 29, 180);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 1, 29);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", 0, 5);
  bar: str-slice("øáéíóúüñ¿éàŤǅǂɊɱʭʬѪ҈ݓ", -80, -200);

}