foo {
  test-1: true;
  test-2: true;
  test-3: true;
  test-4: true;
  test-5: false;
  test-6: false;
  test-7: false;
  test-8: false;
  test-9: literal==interpolant;
  test-10: literal ==interpolant;
  test-11: literal== interpolant;
  test-12: literal == interpolant;
  test-13: falseritlp;
  test-14: falseritlp;
  test-15: falseritlp;
  test-16: falseritlp;
  test-17: literal==litlp_rschema;
  test-18: literal ==litlp_rschema;
  test-19: literal== litlp_rschema;
  test-20: literal == litlp_rschema;
  test-21: true;
  test-22: true;
  test-23: true;
  test-24: true;
  test-25: "quoted"==interpolant;
  test-26: "quoted" ==interpolant;
  test-27: "quoted"== interpolant;
  test-28: "quoted" == interpolant;
  test-29: falseritlp;
  test-30: falseritlp;
  test-31: falseritlp;
  test-32: falseritlp;
  test-33: "quoted"==litlp_rschema;
  test-34: "quoted" ==litlp_rschema;
  test-35: "quoted"== litlp_rschema;
  test-36: "quoted" == litlp_rschema;
  test-37: interpolant==interpolant;
  test-38: interpolant ==interpolant;
  test-39: interpolant== interpolant;
  test-40: interpolant == interpolant;
  test-41: interpolant==lschema_ritlp;
  test-42: interpolant ==lschema_ritlp;
  test-43: interpolant== lschema_ritlp;
  test-44: interpolant == lschema_ritlp;
  test-45: interpolant==litlp_rschema;
  test-46: interpolant ==litlp_rschema;
  test-47: interpolant== litlp_rschema;
  test-48: interpolant == litlp_rschema;
  test-49: lschema_ritlp==lschema_ritlp;
  test-50: lschema_ritlp ==lschema_ritlp;
  test-51: lschema_ritlp== lschema_ritlp;
  test-52: lschema_ritlp == lschema_ritlp;
  test-53: lschema_ritlp==litlp_rschema;
  test-54: lschema_ritlp ==litlp_rschema;
  test-55: lschema_ritlp== litlp_rschema;
  test-56: lschema_ritlp == litlp_rschema;
  test-57: litlp_rschema==litlp_rschema;
  test-58: litlp_rschema ==litlp_rschema;
  test-59: litlp_rschema== litlp_rschema;
  test-60: litlp_rschema == litlp_rschema; }
