foo { test-1: true; test-2: true; test-3: true; test-4: true; test-5: true; test-6: true; test-7: true; test-8: true; test-9: 10==10px; test-10: 10 ==10px; test-11: 10== 10px; test-12: 10 == 10px; test-13: false0px; test-14: false0px; test-15: false0px; test-16: false0px; test-17: truepx; test-18: truepx; test-19: truepx; test-20: truepx; test-21: truepx; test-22: truepx; test-23: truepx; test-24: truepx; test-25: true; test-26: true; test-27: true; test-28: true; test-29: 10px==10px; test-30: 10px ==10px; test-31: 10px== 10px; test-32: 10px == 10px; test-33: false0px; test-34: false0px; test-35: false0px; test-36: false0px; test-37: truepx; test-38: truepx; test-39: truepx; test-40: truepx; test-41: truepx; test-42: truepx; test-43: truepx; test-44: truepx; test-45: 10px==10px; test-46: 10px ==10px; test-47: 10px== 10px; test-48: 10px == 10px; test-49: 10false0px; test-50: 10false0px; test-51: 10false0px; test-52: 10false0px; test-53: 10falsepx; test-54: 10falsepx; test-55: 10falsepx; test-56: 10falsepx; test-57: 10falsepx; test-58: 10falsepx; test-59: 10falsepx; test-60: 10falsepx; test-61: 10false0px; test-62: 10false0px; test-63: 10false0px; test-64: 10false0px; test-65: 10falsepx; test-66: 10falsepx; test-67: 10falsepx; test-68: 10falsepx; test-69: 10falsepx; test-70: 10falsepx; test-71: 10falsepx; test-72: 10falsepx; test-73: 10px==10px; test-74: 10px ==10px; test-75: 10px== 10px; test-76: 10px == 10px; test-77: 10px==10px; test-78: 10px ==10px; test-79: 10px== 10px; test-80: 10px == 10px; test-81: 10pfalsepx; test-82: 10pfalsepx; test-83: 10pfalsepx; test-84: 10pfalsepx; }
