universal-selector {
  test-01: is-superselector("*", "*");
  test-02: is-superselector("|*", "*");
  test-03: is-superselector("*|*", "*");
  test-04: is-superselector("*", "|*");
  test-05: is-superselector("|*", "|*");
  test-06: is-superselector("*|*", "|*");
  test-07: is-superselector("*", "*|*");
  test-08: is-superselector("|*", "*|*");
  test-09: is-superselector("*|*", "*|*");
}
