.result{output:1deg;output:4.2;output:4.2deg;output:.9deg;output:4.66667;output:4.2grad;output:57.29578deg;output:.0733;output:4.2rad;output:360deg;output:.01167;output:4.2turn;output:1.11111grad;output:3.78;output:4.2deg;output:1grad;output:4.2;output:4.2grad;output:63.66198grad;output:.06597;output:4.2rad;output:400grad;output:.0105;output:4.2turn;output:.01745rad;output:240.64227;output:4.2deg;output:.01571rad;output:267.3803;output:4.2grad;output:1rad;output:4.2;output:4.2rad;output:6.28319rad;output:.66845;output:4.2turn;output:.00278turn;output:1512;output:4.2deg;output:.0025turn;output:1680;output:4.2grad;output:.15915turn;output:26.38938;output:4.2rad;output:1turn;output:4.2;output:4.2turn}
