foo {
  c0: black;
  c1: black;
  c2: black;
  c3: black;
  c4: black;
  c5: black;
  c6: black;
  c7: black;
  c8: black;
  c9: black;
  c10: black;
  c11: black;
  c12: black;
  c13: black;
  c14: black;
  c15: black;
  c16: black;
  c17: black;
  c18: black;
  c19: black;
  c20: black;
  c21: black;
  c22: black;
  c23: black;
  c24: black;
  c25: black;
  c26: black;
  c27: black;
  c28: black;
  c29: black;
  c30: black;
  c31: black;
  c32: black;
  c33: black;
  c34: black;
  c35: black;
  c36: black;
  c37: black;
  c38: black;
  c39: black;
  c40: black;
  c41: black;
  c42: black;
  c43: black;
  c44: black;
  c45: black;
  c46: black;
  c47: black;
  c48: black;
  c49: black;
  c50: black;
  c51: black;
  c52: black;
  c53: black;
  c54: black;
  c55: black;
  c56: black;
  c57: black;
  c58: black;
  c59: black;
  c60: black;
  c61: black;
  c62: black;
  c63: black;
  c64: black;
  c65: black;
  c66: black;
  c67: black;
  c68: black;
  c69: black;
  c70: black;
  c71: black;
  c72: black;
  c73: black;
  c74: black;
  c75: black;
  c76: black;
  c77: black;
  c78: black;
  c79: black;
  c80: black;
  c81: black;
  c82: black;
  c83: black;
  c84: black;
  c85: black;
  c86: black;
  c87: black;
  c88: black;
  c89: black;
  c90: black;
  c91: black;
  c92: black;
  c93: black;
  c94: black;
  c95: black;
  c96: black;
  c97: black;
  c98: black;
  c99: black;
  c100: black; }
