@function foobar($x, $y, $z : 3) {
  @return $x + $y * 2 + $z
}

.foobar {
  content: foobar($y:2, $x:4);
  content: foobar($y: 2, $x: 4);
  content: foobar($y : 2, $x : 4);
  content: foobar($y:2px, $x:4);
  content: foobar($y: 2px, $x: 4);
  content: foobar($y : 2px, $x : 4);
}