.script {
  // All script values except interpolation are interpreted statically.
  --variable: $variable;
  --operator: 1 + 1;
  --function: red(#ffffff);
  --list: (a b c);
  --map: (a: b, c: d);
}
