a {
  b: "bar", "bar";
  b: "bar", "bar";
}

b {
  b: bar, bar;
  b: bar, bar;
}

c {
  b: "foo", bar;
}

d {
  b: foo, bar;
  b: foo, bar;
}

e {
  b: foo,bar;
  b: foo,bar;
}

f {
  b: "foo,bar";
  b: "foo,bar";
}
