.simple {
  --single: value;
  --multiple: value1 value2;
  --function: foo(bar);
  --url: url(http://foo.com/bar);
  --color: #foo;
  --exponent: 12.6e7;
  --close-comment: */;
  --empty: ;
  --single-line: // (
    );
  --no-extra-whitespace:value; }
