test { num_deg: 53deg; num_grad: 53grad; num_rad: 53rad; num_turn: 53turn; deg_num: 53deg; deg_grad: 48.8deg; deg_rad: 2417.42274deg; deg_turn: 371deg; grad_num: 12.5grad; grad_rad: 2684.80304grad; grad_turn: 211grad; rad_num: 12.5rad; rad_turn: 14.14159rad; }
