.interpolation {
  // Interpolation is the only Sass construct that's supported in custom
  // variables.
  --alone: #{1 + 2};
  --in-list: a #{1 + 2} c;
  --in-ident: foo#{1 + 2}bar;
  --in-string: "foo#{1 + 2}bar";
  --in-uri: uri(foo#{1 + 2}bar);
}
