div {
  $list: append(1/2 3, 4);
  content: (1 2 3) == (1, 2, 3);
  content: (1 2 3) == (1 2 3);
  content: var $list;
  content: lit (1/2 3 4);
  content: (1/2 3 4) == $list;
  a: length((1/2 3 4)), length($list);
  b: nth((1/2 3 4), 1), nth($list, 1);
  content: (1/2 3 4) == (1/2 3 4);
  /***/
  content: length($list);
  content: type-of(nth($list, 1));
  content: nth($list, 1);
  content: nth(1/2 3 4, 1);
  $a: 1 2 3;
  $b: (1 2 3);
  content: $a == $b;
  content: 1 2 () 3;
  color: red == #ff0000;
  $color-list : fudge red blue;
  color: nth($color-list, 2) == #ff0000;
  color: nth($color-list, 2) == red;
}