foo {
  // c-1: change-color(red,$lightness:-1);
  c0: change-color(red,$lightness:0);
  c1: change-color(red,$lightness:1);
  c2: change-color(red,$lightness:2);
  c3: change-color(red,$lightness:3);
  c4: change-color(red,$lightness:4);
  c5: change-color(red,$lightness:5);
  c6: change-color(red,$lightness:6);
  c7: change-color(red,$lightness:7);
  c8: change-color(red,$lightness:8);
  c9: change-color(red,$lightness:9);
  c10: change-color(red,$lightness:10);
  c11: change-color(red,$lightness:11);
  c12: change-color(red,$lightness:12);
  c13: change-color(red,$lightness:13);
  c14: change-color(red,$lightness:14);
  c15: change-color(red,$lightness:15);
  c16: change-color(red,$lightness:16);
  c17: change-color(red,$lightness:17);
  c18: change-color(red,$lightness:18);
  c19: change-color(red,$lightness:19);
  c20: change-color(red,$lightness:20);
  c21: change-color(red,$lightness:21);
  c22: change-color(red,$lightness:22);
  c23: change-color(red,$lightness:23);
  c24: change-color(red,$lightness:24);
  c25: change-color(red,$lightness:25);
  c26: change-color(red,$lightness:26);
  c27: change-color(red,$lightness:27);
  c28: change-color(red,$lightness:28);
  c29: change-color(red,$lightness:29);
  c30: change-color(red,$lightness:30);
  c31: change-color(red,$lightness:31);
  c32: change-color(red,$lightness:32);
  c33: change-color(red,$lightness:33);
  c34: change-color(red,$lightness:34);
  c35: change-color(red,$lightness:35);
  c36: change-color(red,$lightness:36);
  c37: change-color(red,$lightness:37);
  c38: change-color(red,$lightness:38);
  c39: change-color(red,$lightness:39);
  c40: change-color(red,$lightness:40);
  c41: change-color(red,$lightness:41);
  c42: change-color(red,$lightness:42);
  c43: change-color(red,$lightness:43);
  c44: change-color(red,$lightness:44);
  c45: change-color(red,$lightness:45);
  c46: change-color(red,$lightness:46);
  c47: change-color(red,$lightness:47);
  c48: change-color(red,$lightness:48);
  c49: change-color(red,$lightness:49);
  c50: change-color(red,$lightness:50);
  c51: change-color(red,$lightness:51);
  c52: change-color(red,$lightness:52);
  c53: change-color(red,$lightness:53);
  c54: change-color(red,$lightness:54);
  c55: change-color(red,$lightness:55);
  c56: change-color(red,$lightness:56);
  c57: change-color(red,$lightness:57);
  c58: change-color(red,$lightness:58);
  c59: change-color(red,$lightness:59);
  c60: change-color(red,$lightness:60);
  c61: change-color(red,$lightness:61);
  c62: change-color(red,$lightness:62);
  c63: change-color(red,$lightness:63);
  c64: change-color(red,$lightness:64);
  c65: change-color(red,$lightness:65);
  c66: change-color(red,$lightness:66);
  c67: change-color(red,$lightness:67);
  c68: change-color(red,$lightness:68);
  c69: change-color(red,$lightness:69);
  c70: change-color(red,$lightness:70);
  c71: change-color(red,$lightness:71);
  c72: change-color(red,$lightness:72);
  c73: change-color(red,$lightness:73);
  c74: change-color(red,$lightness:74);
  c75: change-color(red,$lightness:75);
  c76: change-color(red,$lightness:76);
  c77: change-color(red,$lightness:77);
  c78: change-color(red,$lightness:78);
  c79: change-color(red,$lightness:79);
  c80: change-color(red,$lightness:80);
  c81: change-color(red,$lightness:81);
  c82: change-color(red,$lightness:82);
  c83: change-color(red,$lightness:83);
  c84: change-color(red,$lightness:84);
  c85: change-color(red,$lightness:85);
  c86: change-color(red,$lightness:86);
  c87: change-color(red,$lightness:87);
  c88: change-color(red,$lightness:88);
  c89: change-color(red,$lightness:89);
  c90: change-color(red,$lightness:90);
  c91: change-color(red,$lightness:91);
  c92: change-color(red,$lightness:92);
  c93: change-color(red,$lightness:93);
  c94: change-color(red,$lightness:94);
  c95: change-color(red,$lightness:95);
  c96: change-color(red,$lightness:96);
  c97: change-color(red,$lightness:97);
  c98: change-color(red,$lightness:98);
  c99: change-color(red,$lightness:99);
  // c100: change-color(red,$lightness:100);
}
