.result {
  output: 1s;
  output: 4.2;
  output: 4.2s;
  output: 0.001s;
  output: 4200;
  output: 4.2ms;
  output: 1000ms;
  output: 0.0042;
  output: 4.2s;
  output: 1ms;
  output: 4.2;
  output: 4.2ms;
}
