@function foo() {
  @return "hello";
}

@mixin foo() {
  content: "hello";
}

div {
  span {
    @function length($a, $b, $c, $d) {
      @return $a + $b + $c + $d;
    }

    div {
      content: foo();
      @include foo();
      width: length(1,2,2,3);
    }
  }

  height: length(a b c d e);

}