colors{AliceBlue:#f0f8ff;AntiqueWhite:#faebd7;Aqua:cyan;Aquamarine:#7fffd4;Azure:azure;Beige:beige;Bisque:bisque;Black:#000;BlanchedAlmond:#ffebcd;Blue:blue;BlueViolet:#8a2be2;Brown:brown;BurlyWood:#deb887;CadetBlue:#5f9ea0;Chartreuse:#7fff00;Chocolate:#d2691e;Coral:coral;CornflowerBlue:#6495ed;Cornsilk:#fff8dc;Crimson:crimson;Cyan:cyan;DarkBlue:#00008b;DarkCyan:#008b8b;DarkGoldenRod:#b8860b;DarkGray:#a9a9a9;DarkGreen:#006400;DarkKhaki:#bdb76b;DarkMagenta:#8b008b;DarkOliveGreen:#556b2f;Darkorange:#ff8c00;DarkOrchid:#9932cc;DarkRed:darkred;DarkSalmon:#e9967a;DarkSeaGreen:#8fbc8f;DarkSlateBlue:#483d8b;DarkSlateGray:#2f4f4f;DarkTurquoise:#00ced1;DarkViolet:#9400d3;DeepPink:#ff1493;DeepSkyBlue:#00bfff;DimGray:dimgray;DodgerBlue:#1e90ff;FireBrick:#b22222;FloralWhite:#fffaf0;ForestGreen:#228b22;Fuchsia:#f0f;Gainsboro:#dcdcdc;GhostWhite:#f8f8ff;Gold:gold;GoldenRod:#daa520;Gray:gray;Green:green;GreenYellow:#adff2f;HoneyDew:#f0fff0;HotPink:hotpink;IndianRed:#cd5c5c;Indigo:indigo;Ivory:ivory;Khaki:khaki;Lavender:#e6e6fa;LavenderBlush:#fff0f5;LawnGreen:#7cfc00;LemonChiffon:#fffacd;LightBlue:#add8e6;LightCoral:#f08080;LightCyan:#e0ffff;LightGoldenRodYellow:#fafad2;LightGray:#d3d3d3;LightGreen:#90ee90;LightPink:#ffb6c1;LightSalmon:#ffa07a;LightSeaGreen:#20b2aa;LightSkyBlue:#87cefa;LightSlateGray:#789;LightSteelBlue:#b0c4de;LightYellow:#ffffe0;Lime:lime;LimeGreen:#32cd32;Linen:linen;Magenta:#f0f;Maroon:maroon;MediumAquaMarine:#66cdaa;MediumBlue:#0000cd;MediumOrchid:#ba55d3;MediumPurple:#9370db;MediumSeaGreen:#3cb371;MediumSlateBlue:#7b68ee;MediumSpringGreen:#00fa9a;MediumTurquoise:#48d1cc;MediumVioletRed:#c71585;MidnightBlue:#191970;MintCream:#f5fffa;MistyRose:#ffe4e1;Moccasin:#ffe4b5;NavajoWhite:#ffdead;Navy:navy;OldLace:oldlace;Olive:olive;OliveDrab:#6b8e23;Orange:orange;OrangeRed:#ff4500;Orchid:orchid;PaleGoldenRod:#eee8aa;PaleGreen:#98fb98;PaleTurquoise:#afeeee;PaleVioletRed:#db7093;PapayaWhip:#ffefd5;PeachPuff:#ffdab9;Peru:peru;Pink:pink;Plum:plum;PowderBlue:#b0e0e6;Purple:purple;Red:red;RosyBrown:#bc8f8f;RoyalBlue:#4169e1;SaddleBrown:#8b4513;Salmon:salmon;SandyBrown:#f4a460;SeaGreen:#2e8b57;SeaShell:#fff5ee;Sienna:sienna;Silver:silver;SkyBlue:skyblue;SlateBlue:#6a5acd;SlateGray:#708090;Snow:snow;SpringGreen:#00ff7f;SteelBlue:#4682b4;Tan:tan;Teal:teal;Thistle:thistle;Tomato:tomato;Turquoise:#40e0d0;Violet:violet;Wheat:wheat;White:#fff;WhiteSmoke:#f5f5f5;Yellow:#ff0;YellowGreen:#9acd32;RebeccaPurple:#639;transparent:transparent}
