$my-cool-var: "hello";
@mixin my-cool-mixin($yada-yada) {
  blah: blah;
  hi: $yada_yada;
}
@function my-cool-function($cool_arg) {
  @return $cool-arg;
}

div {
  @include my_cool-mixin($yada_yada: "hi");
  @include my_cool-mixin($my_cool-var);
  foo: my-cool_function($cool-arg: "boop");
  foo: my-cool_function($my-cool_var);
  bar: $my_cool_var;
}

@each $my_cool_var in a, b, c {
  div {
    color: $my-cool-var;
  }
}

@for $my_cool_var from 1 to 10 {
  div {
    color: $my-cool-var;
  }
}


@function blah_blah() {
  @return blah;
}

div {
  foo: blah-blah();
}