foo {
  // c-101: adjust-color(red,$saturation:-101);
  c-100: adjust-color(red,$saturation:-100);
  c-99: adjust-color(red,$saturation:-99);
  c-98: adjust-color(red,$saturation:-98);
  c-97: adjust-color(red,$saturation:-97);
  c-96: adjust-color(red,$saturation:-96);
  c-95: adjust-color(red,$saturation:-95);
  c-94: adjust-color(red,$saturation:-94);
  c-93: adjust-color(red,$saturation:-93);
  c-92: adjust-color(red,$saturation:-92);
  c-91: adjust-color(red,$saturation:-91);
  c-90: adjust-color(red,$saturation:-90);
  c-89: adjust-color(red,$saturation:-89);
  c-88: adjust-color(red,$saturation:-88);
  c-87: adjust-color(red,$saturation:-87);
  c-86: adjust-color(red,$saturation:-86);
  c-85: adjust-color(red,$saturation:-85);
  c-84: adjust-color(red,$saturation:-84);
  c-83: adjust-color(red,$saturation:-83);
  c-82: adjust-color(red,$saturation:-82);
  c-81: adjust-color(red,$saturation:-81);
  c-80: adjust-color(red,$saturation:-80);
  c-79: adjust-color(red,$saturation:-79);
  c-78: adjust-color(red,$saturation:-78);
  c-77: adjust-color(red,$saturation:-77);
  c-76: adjust-color(red,$saturation:-76);
  c-75: adjust-color(red,$saturation:-75);
  c-74: adjust-color(red,$saturation:-74);
  c-73: adjust-color(red,$saturation:-73);
  c-72: adjust-color(red,$saturation:-72);
  c-71: adjust-color(red,$saturation:-71);
  c-70: adjust-color(red,$saturation:-70);
  c-69: adjust-color(red,$saturation:-69);
  c-68: adjust-color(red,$saturation:-68);
  c-67: adjust-color(red,$saturation:-67);
  c-66: adjust-color(red,$saturation:-66);
  c-65: adjust-color(red,$saturation:-65);
  c-64: adjust-color(red,$saturation:-64);
  c-63: adjust-color(red,$saturation:-63);
  c-62: adjust-color(red,$saturation:-62);
  c-61: adjust-color(red,$saturation:-61);
  c-60: adjust-color(red,$saturation:-60);
  c-59: adjust-color(red,$saturation:-59);
  c-58: adjust-color(red,$saturation:-58);
  c-57: adjust-color(red,$saturation:-57);
  c-56: adjust-color(red,$saturation:-56);
  c-55: adjust-color(red,$saturation:-55);
  c-54: adjust-color(red,$saturation:-54);
  c-53: adjust-color(red,$saturation:-53);
  c-52: adjust-color(red,$saturation:-52);
  c-51: adjust-color(red,$saturation:-51);
  c-50: adjust-color(red,$saturation:-50);
  c-49: adjust-color(red,$saturation:-49);
  c-48: adjust-color(red,$saturation:-48);
  c-47: adjust-color(red,$saturation:-47);
  c-46: adjust-color(red,$saturation:-46);
  c-45: adjust-color(red,$saturation:-45);
  c-44: adjust-color(red,$saturation:-44);
  c-43: adjust-color(red,$saturation:-43);
  c-42: adjust-color(red,$saturation:-42);
  c-41: adjust-color(red,$saturation:-41);
  c-40: adjust-color(red,$saturation:-40);
  c-39: adjust-color(red,$saturation:-39);
  c-38: adjust-color(red,$saturation:-38);
  c-37: adjust-color(red,$saturation:-37);
  c-36: adjust-color(red,$saturation:-36);
  c-35: adjust-color(red,$saturation:-35);
  c-34: adjust-color(red,$saturation:-34);
  c-33: adjust-color(red,$saturation:-33);
  c-32: adjust-color(red,$saturation:-32);
  c-31: adjust-color(red,$saturation:-31);
  c-30: adjust-color(red,$saturation:-30);
  c-29: adjust-color(red,$saturation:-29);
  c-28: adjust-color(red,$saturation:-28);
  c-27: adjust-color(red,$saturation:-27);
  c-26: adjust-color(red,$saturation:-26);
  c-25: adjust-color(red,$saturation:-25);
  c-24: adjust-color(red,$saturation:-24);
  c-23: adjust-color(red,$saturation:-23);
  c-22: adjust-color(red,$saturation:-22);
  c-21: adjust-color(red,$saturation:-21);
  c-20: adjust-color(red,$saturation:-20);
  c-19: adjust-color(red,$saturation:-19);
  c-18: adjust-color(red,$saturation:-18);
  c-17: adjust-color(red,$saturation:-17);
  c-16: adjust-color(red,$saturation:-16);
  c-15: adjust-color(red,$saturation:-15);
  c-14: adjust-color(red,$saturation:-14);
  c-13: adjust-color(red,$saturation:-13);
  c-12: adjust-color(red,$saturation:-12);
  c-11: adjust-color(red,$saturation:-11);
  c-10: adjust-color(red,$saturation:-10);
  c-9: adjust-color(red,$saturation:-9);
  c-8: adjust-color(red,$saturation:-8);
  c-7: adjust-color(red,$saturation:-7);
  c-6: adjust-color(red,$saturation:-6);
  c-5: adjust-color(red,$saturation:-5);
  c-4: adjust-color(red,$saturation:-4);
  c-3: adjust-color(red,$saturation:-3);
  c-2: adjust-color(red,$saturation:-2);
  c-1: adjust-color(red,$saturation:-1);
  c0: adjust-color(red,$saturation:0);
  c1: adjust-color(red,$saturation:1);
  c2: adjust-color(red,$saturation:2);
  c3: adjust-color(red,$saturation:3);
  c4: adjust-color(red,$saturation:4);
  c5: adjust-color(red,$saturation:5);
  c6: adjust-color(red,$saturation:6);
  c7: adjust-color(red,$saturation:7);
  c8: adjust-color(red,$saturation:8);
  c9: adjust-color(red,$saturation:9);
  c10: adjust-color(red,$saturation:10);
  c11: adjust-color(red,$saturation:11);
  c12: adjust-color(red,$saturation:12);
  c13: adjust-color(red,$saturation:13);
  c14: adjust-color(red,$saturation:14);
  c15: adjust-color(red,$saturation:15);
  c16: adjust-color(red,$saturation:16);
  c17: adjust-color(red,$saturation:17);
  c18: adjust-color(red,$saturation:18);
  c19: adjust-color(red,$saturation:19);
  c20: adjust-color(red,$saturation:20);
  c21: adjust-color(red,$saturation:21);
  c22: adjust-color(red,$saturation:22);
  c23: adjust-color(red,$saturation:23);
  c24: adjust-color(red,$saturation:24);
  c25: adjust-color(red,$saturation:25);
  c26: adjust-color(red,$saturation:26);
  c27: adjust-color(red,$saturation:27);
  c28: adjust-color(red,$saturation:28);
  c29: adjust-color(red,$saturation:29);
  c30: adjust-color(red,$saturation:30);
  c31: adjust-color(red,$saturation:31);
  c32: adjust-color(red,$saturation:32);
  c33: adjust-color(red,$saturation:33);
  c34: adjust-color(red,$saturation:34);
  c35: adjust-color(red,$saturation:35);
  c36: adjust-color(red,$saturation:36);
  c37: adjust-color(red,$saturation:37);
  c38: adjust-color(red,$saturation:38);
  c39: adjust-color(red,$saturation:39);
  c40: adjust-color(red,$saturation:40);
  c41: adjust-color(red,$saturation:41);
  c42: adjust-color(red,$saturation:42);
  c43: adjust-color(red,$saturation:43);
  c44: adjust-color(red,$saturation:44);
  c45: adjust-color(red,$saturation:45);
  c46: adjust-color(red,$saturation:46);
  c47: adjust-color(red,$saturation:47);
  c48: adjust-color(red,$saturation:48);
  c49: adjust-color(red,$saturation:49);
  c50: adjust-color(red,$saturation:50);
  c51: adjust-color(red,$saturation:51);
  c52: adjust-color(red,$saturation:52);
  c53: adjust-color(red,$saturation:53);
  c54: adjust-color(red,$saturation:54);
  c55: adjust-color(red,$saturation:55);
  c56: adjust-color(red,$saturation:56);
  c57: adjust-color(red,$saturation:57);
  c58: adjust-color(red,$saturation:58);
  c59: adjust-color(red,$saturation:59);
  c60: adjust-color(red,$saturation:60);
  c61: adjust-color(red,$saturation:61);
  c62: adjust-color(red,$saturation:62);
  c63: adjust-color(red,$saturation:63);
  c64: adjust-color(red,$saturation:64);
  c65: adjust-color(red,$saturation:65);
  c66: adjust-color(red,$saturation:66);
  c67: adjust-color(red,$saturation:67);
  c68: adjust-color(red,$saturation:68);
  c69: adjust-color(red,$saturation:69);
  c70: adjust-color(red,$saturation:70);
  c71: adjust-color(red,$saturation:71);
  c72: adjust-color(red,$saturation:72);
  c73: adjust-color(red,$saturation:73);
  c74: adjust-color(red,$saturation:74);
  c75: adjust-color(red,$saturation:75);
  c76: adjust-color(red,$saturation:76);
  c77: adjust-color(red,$saturation:77);
  c78: adjust-color(red,$saturation:78);
  c79: adjust-color(red,$saturation:79);
  c80: adjust-color(red,$saturation:80);
  c81: adjust-color(red,$saturation:81);
  c82: adjust-color(red,$saturation:82);
  c83: adjust-color(red,$saturation:83);
  c84: adjust-color(red,$saturation:84);
  c85: adjust-color(red,$saturation:85);
  c86: adjust-color(red,$saturation:86);
  c87: adjust-color(red,$saturation:87);
  c88: adjust-color(red,$saturation:88);
  c89: adjust-color(red,$saturation:89);
  c90: adjust-color(red,$saturation:90);
  c91: adjust-color(red,$saturation:91);
  c92: adjust-color(red,$saturation:92);
  c93: adjust-color(red,$saturation:93);
  c94: adjust-color(red,$saturation:94);
  c95: adjust-color(red,$saturation:95);
  c96: adjust-color(red,$saturation:96);
  c97: adjust-color(red,$saturation:97);
  c98: adjust-color(red,$saturation:98);
  c99: adjust-color(red,$saturation:99);
  c100: adjust-color(red,$saturation:100);
  // c101: adjust-color(red,$saturation:101);
}
