@function foo() {
  @return "bar";
}

@function bar() {
    @return "foo" + "," + bar;
}

a {
  b: foo(), "bar";
  b: foo(), "bar"
}

b {
  b: #{foo(), "bar"};
  b: #{foo(), "bar"}
}

c {
  b: "foo", bar;
}

d {
  b: #{"foo", bar};
  b: #{"foo", bar}
}

e {
  b: #{bar()};
  b: #{bar()}
}

f {
  b: "foo" + "," + bar;
  b: "foo" + "," + bar
}
