.function-name {
  start: 2foo(arg);
  mid: foo2bar(arg);
  end: foo2(arg);
  full: foo(arg);
  evaluates-args: foo2bar(4);
  supports-splats: foo2bar(1, 2, 3, 4, 5);
  not-built-in-function: quote(arg);
  not-user-defined-function: identity(arg);
  followed-by-function: bored(arg); }
