@media (pointer: none) { .foo { content: foo; } }
@media (pointer: none) and (scripting) { .foo { content: baz; } }

@media (pointer: none) and (scripting) and (light-level: dim) { .foo { content: bar; } }
