foo {
  // c-101: scale-color(red,$green:-101%);
  c-100: scale-color(red,$green:-100%);
  c-99: scale-color(red,$green:-99%);
  c-98: scale-color(red,$green:-98%);
  c-97: scale-color(red,$green:-97%);
  c-96: scale-color(red,$green:-96%);
  c-95: scale-color(red,$green:-95%);
  c-94: scale-color(red,$green:-94%);
  c-93: scale-color(red,$green:-93%);
  c-92: scale-color(red,$green:-92%);
  c-91: scale-color(red,$green:-91%);
  c-90: scale-color(red,$green:-90%);
  c-89: scale-color(red,$green:-89%);
  c-88: scale-color(red,$green:-88%);
  c-87: scale-color(red,$green:-87%);
  c-86: scale-color(red,$green:-86%);
  c-85: scale-color(red,$green:-85%);
  c-84: scale-color(red,$green:-84%);
  c-83: scale-color(red,$green:-83%);
  c-82: scale-color(red,$green:-82%);
  c-81: scale-color(red,$green:-81%);
  c-80: scale-color(red,$green:-80%);
  c-79: scale-color(red,$green:-79%);
  c-78: scale-color(red,$green:-78%);
  c-77: scale-color(red,$green:-77%);
  c-76: scale-color(red,$green:-76%);
  c-75: scale-color(red,$green:-75%);
  c-74: scale-color(red,$green:-74%);
  c-73: scale-color(red,$green:-73%);
  c-72: scale-color(red,$green:-72%);
  c-71: scale-color(red,$green:-71%);
  c-70: scale-color(red,$green:-70%);
  c-69: scale-color(red,$green:-69%);
  c-68: scale-color(red,$green:-68%);
  c-67: scale-color(red,$green:-67%);
  c-66: scale-color(red,$green:-66%);
  c-65: scale-color(red,$green:-65%);
  c-64: scale-color(red,$green:-64%);
  c-63: scale-color(red,$green:-63%);
  c-62: scale-color(red,$green:-62%);
  c-61: scale-color(red,$green:-61%);
  c-60: scale-color(red,$green:-60%);
  c-59: scale-color(red,$green:-59%);
  c-58: scale-color(red,$green:-58%);
  c-57: scale-color(red,$green:-57%);
  c-56: scale-color(red,$green:-56%);
  c-55: scale-color(red,$green:-55%);
  c-54: scale-color(red,$green:-54%);
  c-53: scale-color(red,$green:-53%);
  c-52: scale-color(red,$green:-52%);
  c-51: scale-color(red,$green:-51%);
  c-50: scale-color(red,$green:-50%);
  c-49: scale-color(red,$green:-49%);
  c-48: scale-color(red,$green:-48%);
  c-47: scale-color(red,$green:-47%);
  c-46: scale-color(red,$green:-46%);
  c-45: scale-color(red,$green:-45%);
  c-44: scale-color(red,$green:-44%);
  c-43: scale-color(red,$green:-43%);
  c-42: scale-color(red,$green:-42%);
  c-41: scale-color(red,$green:-41%);
  c-40: scale-color(red,$green:-40%);
  c-39: scale-color(red,$green:-39%);
  c-38: scale-color(red,$green:-38%);
  c-37: scale-color(red,$green:-37%);
  c-36: scale-color(red,$green:-36%);
  c-35: scale-color(red,$green:-35%);
  c-34: scale-color(red,$green:-34%);
  c-33: scale-color(red,$green:-33%);
  c-32: scale-color(red,$green:-32%);
  c-31: scale-color(red,$green:-31%);
  c-30: scale-color(red,$green:-30%);
  c-29: scale-color(red,$green:-29%);
  c-28: scale-color(red,$green:-28%);
  c-27: scale-color(red,$green:-27%);
  c-26: scale-color(red,$green:-26%);
  c-25: scale-color(red,$green:-25%);
  c-24: scale-color(red,$green:-24%);
  c-23: scale-color(red,$green:-23%);
  c-22: scale-color(red,$green:-22%);
  c-21: scale-color(red,$green:-21%);
  c-20: scale-color(red,$green:-20%);
  c-19: scale-color(red,$green:-19%);
  c-18: scale-color(red,$green:-18%);
  c-17: scale-color(red,$green:-17%);
  c-16: scale-color(red,$green:-16%);
  c-15: scale-color(red,$green:-15%);
  c-14: scale-color(red,$green:-14%);
  c-13: scale-color(red,$green:-13%);
  c-12: scale-color(red,$green:-12%);
  c-11: scale-color(red,$green:-11%);
  c-10: scale-color(red,$green:-10%);
  c-9: scale-color(red,$green:-9%);
  c-8: scale-color(red,$green:-8%);
  c-7: scale-color(red,$green:-7%);
  c-6: scale-color(red,$green:-6%);
  c-5: scale-color(red,$green:-5%);
  c-4: scale-color(red,$green:-4%);
  c-3: scale-color(red,$green:-3%);
  c-2: scale-color(red,$green:-2%);
  c-1: scale-color(red,$green:-1%);
  c0: scale-color(red,$green:0%);
  c1: scale-color(red,$green:1%);
  c2: scale-color(red,$green:2%);
  c3: scale-color(red,$green:3%);
  c4: scale-color(red,$green:4%);
  c5: scale-color(red,$green:5%);
  c6: scale-color(red,$green:6%);
  c7: scale-color(red,$green:7%);
  c8: scale-color(red,$green:8%);
  c9: scale-color(red,$green:9%);
  c10: scale-color(red,$green:10%);
  c11: scale-color(red,$green:11%);
  c12: scale-color(red,$green:12%);
  c13: scale-color(red,$green:13%);
  c14: scale-color(red,$green:14%);
  c15: scale-color(red,$green:15%);
  c16: scale-color(red,$green:16%);
  c17: scale-color(red,$green:17%);
  c18: scale-color(red,$green:18%);
  c19: scale-color(red,$green:19%);
  c20: scale-color(red,$green:20%);
  c21: scale-color(red,$green:21%);
  c22: scale-color(red,$green:22%);
  c23: scale-color(red,$green:23%);
  c24: scale-color(red,$green:24%);
  c25: scale-color(red,$green:25%);
  c26: scale-color(red,$green:26%);
  c27: scale-color(red,$green:27%);
  c28: scale-color(red,$green:28%);
  c29: scale-color(red,$green:29%);
  c30: scale-color(red,$green:30%);
  c31: scale-color(red,$green:31%);
  c32: scale-color(red,$green:32%);
  c33: scale-color(red,$green:33%);
  c34: scale-color(red,$green:34%);
  c35: scale-color(red,$green:35%);
  c36: scale-color(red,$green:36%);
  c37: scale-color(red,$green:37%);
  c38: scale-color(red,$green:38%);
  c39: scale-color(red,$green:39%);
  c40: scale-color(red,$green:40%);
  c41: scale-color(red,$green:41%);
  c42: scale-color(red,$green:42%);
  c43: scale-color(red,$green:43%);
  c44: scale-color(red,$green:44%);
  c45: scale-color(red,$green:45%);
  c46: scale-color(red,$green:46%);
  c47: scale-color(red,$green:47%);
  c48: scale-color(red,$green:48%);
  c49: scale-color(red,$green:49%);
  c50: scale-color(red,$green:50%);
  c51: scale-color(red,$green:51%);
  c52: scale-color(red,$green:52%);
  c53: scale-color(red,$green:53%);
  c54: scale-color(red,$green:54%);
  c55: scale-color(red,$green:55%);
  c56: scale-color(red,$green:56%);
  c57: scale-color(red,$green:57%);
  c58: scale-color(red,$green:58%);
  c59: scale-color(red,$green:59%);
  c60: scale-color(red,$green:60%);
  c61: scale-color(red,$green:61%);
  c62: scale-color(red,$green:62%);
  c63: scale-color(red,$green:63%);
  c64: scale-color(red,$green:64%);
  c65: scale-color(red,$green:65%);
  c66: scale-color(red,$green:66%);
  c67: scale-color(red,$green:67%);
  c68: scale-color(red,$green:68%);
  c69: scale-color(red,$green:69%);
  c70: scale-color(red,$green:70%);
  c71: scale-color(red,$green:71%);
  c72: scale-color(red,$green:72%);
  c73: scale-color(red,$green:73%);
  c74: scale-color(red,$green:74%);
  c75: scale-color(red,$green:75%);
  c76: scale-color(red,$green:76%);
  c77: scale-color(red,$green:77%);
  c78: scale-color(red,$green:78%);
  c79: scale-color(red,$green:79%);
  c80: scale-color(red,$green:80%);
  c81: scale-color(red,$green:81%);
  c82: scale-color(red,$green:82%);
  c83: scale-color(red,$green:83%);
  c84: scale-color(red,$green:84%);
  c85: scale-color(red,$green:85%);
  c86: scale-color(red,$green:86%);
  c87: scale-color(red,$green:87%);
  c88: scale-color(red,$green:88%);
  c89: scale-color(red,$green:89%);
  c90: scale-color(red,$green:90%);
  c91: scale-color(red,$green:91%);
  c92: scale-color(red,$green:92%);
  c93: scale-color(red,$green:93%);
  c94: scale-color(red,$green:94%);
  c95: scale-color(red,$green:95%);
  c96: scale-color(red,$green:96%);
  c97: scale-color(red,$green:97%);
  c98: scale-color(red,$green:98%);
  c99: scale-color(red,$green:99%);
  c100: scale-color(red,$green:100%);
  // c101: scale-color(red,$green:101%);
}
