foo {
  color: blue;

  @at-root {
    bar {
      color: red;
    }
  }
}

foo {
  color: blue;

  @at-root bar {
    color: red;
  }
}

foo {
  color: blue;

  @at-root bar {
    baz {
      color: red;
    }
  }
}

foo {
  color: blue;

  @at-root {
    bar {
      baz {
        color: red;
      }
    }
  }
}

