test-1 test-2 test-3 test-4 test-5,
test-6 test-7 test-8 test-9 test-10 {
    @each $set in & {
        set: inspect($set);

        @each $selector in $set {
            selector: inspect($selector);
        }
    }
}

test-1 test-2 test-3 test-4 test-5,
test-6 test-7 test-8 test-9 test-10 {
    @for $i from 1 through length(&) {
        $set: nth(&, $i);
        set: inspect($set);

        @each $selector in $set {
            selector: inspect($selector);
        }
    }
}